// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.36.7
// 	protoc        v6.30.2
// source: spire/api/server/logger/v1/logger.proto

package loggerv1

import (
	types "github.com/spiffe/spire-api-sdk/proto/spire/api/types"
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	reflect "reflect"
	sync "sync"
	unsafe "unsafe"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

// Empty Get Logger Request message for future extension
type GetLoggerRequest struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetLoggerRequest) Reset() {
	*x = GetLoggerRequest{}
	mi := &file_spire_api_server_logger_v1_logger_proto_msgTypes[0]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetLoggerRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetLoggerRequest) ProtoMessage() {}

func (x *GetLoggerRequest) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_logger_v1_logger_proto_msgTypes[0]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetLoggerRequest.ProtoReflect.Descriptor instead.
func (*GetLoggerRequest) Descriptor() ([]byte, []int) {
	return file_spire_api_server_logger_v1_logger_proto_rawDescGZIP(), []int{0}
}

// Set Log Level Request message
type SetLogLevelRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// The new level the logger should assume
	NewLevel      types.LogLevel `protobuf:"varint,1,opt,name=new_level,json=newLevel,proto3,enum=spire.api.types.LogLevel" json:"new_level,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *SetLogLevelRequest) Reset() {
	*x = SetLogLevelRequest{}
	mi := &file_spire_api_server_logger_v1_logger_proto_msgTypes[1]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *SetLogLevelRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*SetLogLevelRequest) ProtoMessage() {}

func (x *SetLogLevelRequest) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_logger_v1_logger_proto_msgTypes[1]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use SetLogLevelRequest.ProtoReflect.Descriptor instead.
func (*SetLogLevelRequest) Descriptor() ([]byte, []int) {
	return file_spire_api_server_logger_v1_logger_proto_rawDescGZIP(), []int{1}
}

func (x *SetLogLevelRequest) GetNewLevel() types.LogLevel {
	if x != nil {
		return x.NewLevel
	}
	return types.LogLevel(0)
}

// Empty Reset Log Level Request message for future extension
type ResetLogLevelRequest struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ResetLogLevelRequest) Reset() {
	*x = ResetLogLevelRequest{}
	mi := &file_spire_api_server_logger_v1_logger_proto_msgTypes[2]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ResetLogLevelRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ResetLogLevelRequest) ProtoMessage() {}

func (x *ResetLogLevelRequest) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_logger_v1_logger_proto_msgTypes[2]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ResetLogLevelRequest.ProtoReflect.Descriptor instead.
func (*ResetLogLevelRequest) Descriptor() ([]byte, []int) {
	return file_spire_api_server_logger_v1_logger_proto_rawDescGZIP(), []int{2}
}

var File_spire_api_server_logger_v1_logger_proto protoreflect.FileDescriptor

const file_spire_api_server_logger_v1_logger_proto_rawDesc = "" +
	"\n" +
	"'spire/api/server/logger/v1/logger.proto\x12\x1aspire.api.server.logger.v1\x1a\x1cspire/api/types/logger.proto\"\x12\n" +
	"\x10GetLoggerRequest\"L\n" +
	"\x12SetLogLevelRequest\x126\n" +
	"\tnew_level\x18\x01 \x01(\x0e2\x19.spire.api.types.LogLevelR\bnewLevel\"\x16\n" +
	"\x14ResetLogLevelRequest2\x90\x02\n" +
	"\x06Logger\x12R\n" +
	"\tGetLogger\x12,.spire.api.server.logger.v1.GetLoggerRequest\x1a\x17.spire.api.types.Logger\x12V\n" +
	"\vSetLogLevel\x12..spire.api.server.logger.v1.SetLogLevelRequest\x1a\x17.spire.api.types.Logger\x12Z\n" +
	"\rResetLogLevel\x120.spire.api.server.logger.v1.ResetLogLevelRequest\x1a\x17.spire.api.types.LoggerBKZIgithub.com/spiffe/spire-api-sdk/proto/spire/api/server/logger/v1;loggerv1b\x06proto3"

var (
	file_spire_api_server_logger_v1_logger_proto_rawDescOnce sync.Once
	file_spire_api_server_logger_v1_logger_proto_rawDescData []byte
)

func file_spire_api_server_logger_v1_logger_proto_rawDescGZIP() []byte {
	file_spire_api_server_logger_v1_logger_proto_rawDescOnce.Do(func() {
		file_spire_api_server_logger_v1_logger_proto_rawDescData = protoimpl.X.CompressGZIP(unsafe.Slice(unsafe.StringData(file_spire_api_server_logger_v1_logger_proto_rawDesc), len(file_spire_api_server_logger_v1_logger_proto_rawDesc)))
	})
	return file_spire_api_server_logger_v1_logger_proto_rawDescData
}

var file_spire_api_server_logger_v1_logger_proto_msgTypes = make([]protoimpl.MessageInfo, 3)
var file_spire_api_server_logger_v1_logger_proto_goTypes = []any{
	(*GetLoggerRequest)(nil),     // 0: spire.api.server.logger.v1.GetLoggerRequest
	(*SetLogLevelRequest)(nil),   // 1: spire.api.server.logger.v1.SetLogLevelRequest
	(*ResetLogLevelRequest)(nil), // 2: spire.api.server.logger.v1.ResetLogLevelRequest
	(types.LogLevel)(0),          // 3: spire.api.types.LogLevel
	(*types.Logger)(nil),         // 4: spire.api.types.Logger
}
var file_spire_api_server_logger_v1_logger_proto_depIdxs = []int32{
	3, // 0: spire.api.server.logger.v1.SetLogLevelRequest.new_level:type_name -> spire.api.types.LogLevel
	0, // 1: spire.api.server.logger.v1.Logger.GetLogger:input_type -> spire.api.server.logger.v1.GetLoggerRequest
	1, // 2: spire.api.server.logger.v1.Logger.SetLogLevel:input_type -> spire.api.server.logger.v1.SetLogLevelRequest
	2, // 3: spire.api.server.logger.v1.Logger.ResetLogLevel:input_type -> spire.api.server.logger.v1.ResetLogLevelRequest
	4, // 4: spire.api.server.logger.v1.Logger.GetLogger:output_type -> spire.api.types.Logger
	4, // 5: spire.api.server.logger.v1.Logger.SetLogLevel:output_type -> spire.api.types.Logger
	4, // 6: spire.api.server.logger.v1.Logger.ResetLogLevel:output_type -> spire.api.types.Logger
	4, // [4:7] is the sub-list for method output_type
	1, // [1:4] is the sub-list for method input_type
	1, // [1:1] is the sub-list for extension type_name
	1, // [1:1] is the sub-list for extension extendee
	0, // [0:1] is the sub-list for field type_name
}

func init() { file_spire_api_server_logger_v1_logger_proto_init() }
func file_spire_api_server_logger_v1_logger_proto_init() {
	if File_spire_api_server_logger_v1_logger_proto != nil {
		return
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: unsafe.Slice(unsafe.StringData(file_spire_api_server_logger_v1_logger_proto_rawDesc), len(file_spire_api_server_logger_v1_logger_proto_rawDesc)),
			NumEnums:      0,
			NumMessages:   3,
			NumExtensions: 0,
			NumServices:   1,
		},
		GoTypes:           file_spire_api_server_logger_v1_logger_proto_goTypes,
		DependencyIndexes: file_spire_api_server_logger_v1_logger_proto_depIdxs,
		MessageInfos:      file_spire_api_server_logger_v1_logger_proto_msgTypes,
	}.Build()
	File_spire_api_server_logger_v1_logger_proto = out.File
	file_spire_api_server_logger_v1_logger_proto_goTypes = nil
	file_spire_api_server_logger_v1_logger_proto_depIdxs = nil
}
