// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.36.7
// 	protoc        v6.30.2
// source: spire/api/types/bundle.proto

package types

import (
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	reflect "reflect"
	sync "sync"
	unsafe "unsafe"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type Bundle struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// The name of the trust domain the bundle belongs to (e.g., "example.org").
	TrustDomain string `protobuf:"bytes,1,opt,name=trust_domain,json=trustDomain,proto3" json:"trust_domain,omitempty"`
	// X.509 authorities for authenticating X509-SVIDs.
	X509Authorities []*X509Certificate `protobuf:"bytes,2,rep,name=x509_authorities,json=x509Authorities,proto3" json:"x509_authorities,omitempty"`
	// JWT authorities for authenticating JWT-SVIDs.
	JwtAuthorities []*JWTKey `protobuf:"bytes,3,rep,name=jwt_authorities,json=jwtAuthorities,proto3" json:"jwt_authorities,omitempty"`
	// A hint on how often the bundle should be refreshed from the bundle
	// provider, in seconds. Can be zero (meaning no hint available).
	RefreshHint int64 `protobuf:"varint,4,opt,name=refresh_hint,json=refreshHint,proto3" json:"refresh_hint,omitempty"`
	// The sequence number of the bundle.
	SequenceNumber uint64 `protobuf:"varint,5,opt,name=sequence_number,json=sequenceNumber,proto3" json:"sequence_number,omitempty"`
	// WIT authorities for authenticating WIT-SVIDs.
	WitAuthorities []*WITKey `protobuf:"bytes,6,rep,name=wit_authorities,json=witAuthorities,proto3" json:"wit_authorities,omitempty"`
	unknownFields  protoimpl.UnknownFields
	sizeCache      protoimpl.SizeCache
}

func (x *Bundle) Reset() {
	*x = Bundle{}
	mi := &file_spire_api_types_bundle_proto_msgTypes[0]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *Bundle) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Bundle) ProtoMessage() {}

func (x *Bundle) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_types_bundle_proto_msgTypes[0]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Bundle.ProtoReflect.Descriptor instead.
func (*Bundle) Descriptor() ([]byte, []int) {
	return file_spire_api_types_bundle_proto_rawDescGZIP(), []int{0}
}

func (x *Bundle) GetTrustDomain() string {
	if x != nil {
		return x.TrustDomain
	}
	return ""
}

func (x *Bundle) GetX509Authorities() []*X509Certificate {
	if x != nil {
		return x.X509Authorities
	}
	return nil
}

func (x *Bundle) GetJwtAuthorities() []*JWTKey {
	if x != nil {
		return x.JwtAuthorities
	}
	return nil
}

func (x *Bundle) GetRefreshHint() int64 {
	if x != nil {
		return x.RefreshHint
	}
	return 0
}

func (x *Bundle) GetSequenceNumber() uint64 {
	if x != nil {
		return x.SequenceNumber
	}
	return 0
}

func (x *Bundle) GetWitAuthorities() []*WITKey {
	if x != nil {
		return x.WitAuthorities
	}
	return nil
}

type X509Certificate struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// The ASN.1 DER encoded bytes of the X.509 certificate.
	Asn1 []byte `protobuf:"bytes,1,opt,name=asn1,proto3" json:"asn1,omitempty"`
	// This authority is no longer secure and must not be used.
	Tainted       bool `protobuf:"varint,2,opt,name=tainted,proto3" json:"tainted,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *X509Certificate) Reset() {
	*x = X509Certificate{}
	mi := &file_spire_api_types_bundle_proto_msgTypes[1]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *X509Certificate) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*X509Certificate) ProtoMessage() {}

func (x *X509Certificate) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_types_bundle_proto_msgTypes[1]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use X509Certificate.ProtoReflect.Descriptor instead.
func (*X509Certificate) Descriptor() ([]byte, []int) {
	return file_spire_api_types_bundle_proto_rawDescGZIP(), []int{1}
}

func (x *X509Certificate) GetAsn1() []byte {
	if x != nil {
		return x.Asn1
	}
	return nil
}

func (x *X509Certificate) GetTainted() bool {
	if x != nil {
		return x.Tainted
	}
	return false
}

type JWTKey struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// The PKIX encoded public key.
	PublicKey []byte `protobuf:"bytes,1,opt,name=public_key,json=publicKey,proto3" json:"public_key,omitempty"`
	// The key identifier.
	KeyId string `protobuf:"bytes,2,opt,name=key_id,json=keyId,proto3" json:"key_id,omitempty"`
	// When the key expires (seconds since Unix epoch). If zero, the key does
	// not expire.
	ExpiresAt int64 `protobuf:"varint,3,opt,name=expires_at,json=expiresAt,proto3" json:"expires_at,omitempty"`
	// This authority is no longer secure and must not be used
	Tainted       bool `protobuf:"varint,4,opt,name=tainted,proto3" json:"tainted,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *JWTKey) Reset() {
	*x = JWTKey{}
	mi := &file_spire_api_types_bundle_proto_msgTypes[2]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *JWTKey) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*JWTKey) ProtoMessage() {}

func (x *JWTKey) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_types_bundle_proto_msgTypes[2]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use JWTKey.ProtoReflect.Descriptor instead.
func (*JWTKey) Descriptor() ([]byte, []int) {
	return file_spire_api_types_bundle_proto_rawDescGZIP(), []int{2}
}

func (x *JWTKey) GetPublicKey() []byte {
	if x != nil {
		return x.PublicKey
	}
	return nil
}

func (x *JWTKey) GetKeyId() string {
	if x != nil {
		return x.KeyId
	}
	return ""
}

func (x *JWTKey) GetExpiresAt() int64 {
	if x != nil {
		return x.ExpiresAt
	}
	return 0
}

func (x *JWTKey) GetTainted() bool {
	if x != nil {
		return x.Tainted
	}
	return false
}

type WITKey struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// The PKIX encoded public key.
	PublicKey []byte `protobuf:"bytes,1,opt,name=public_key,json=publicKey,proto3" json:"public_key,omitempty"`
	// The key identifier.
	KeyId string `protobuf:"bytes,2,opt,name=key_id,json=keyId,proto3" json:"key_id,omitempty"`
	// When the key expires (seconds since Unix epoch). If zero, the key does
	// not expire.
	ExpiresAt int64 `protobuf:"varint,3,opt,name=expires_at,json=expiresAt,proto3" json:"expires_at,omitempty"`
	// This authority is no longer secure and must not be used
	Tainted       bool `protobuf:"varint,4,opt,name=tainted,proto3" json:"tainted,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *WITKey) Reset() {
	*x = WITKey{}
	mi := &file_spire_api_types_bundle_proto_msgTypes[3]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *WITKey) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*WITKey) ProtoMessage() {}

func (x *WITKey) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_types_bundle_proto_msgTypes[3]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use WITKey.ProtoReflect.Descriptor instead.
func (*WITKey) Descriptor() ([]byte, []int) {
	return file_spire_api_types_bundle_proto_rawDescGZIP(), []int{3}
}

func (x *WITKey) GetPublicKey() []byte {
	if x != nil {
		return x.PublicKey
	}
	return nil
}

func (x *WITKey) GetKeyId() string {
	if x != nil {
		return x.KeyId
	}
	return ""
}

func (x *WITKey) GetExpiresAt() int64 {
	if x != nil {
		return x.ExpiresAt
	}
	return 0
}

func (x *WITKey) GetTainted() bool {
	if x != nil {
		return x.Tainted
	}
	return false
}

type BundleMask struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// x509_authorities field mask.
	X509Authorities bool `protobuf:"varint,2,opt,name=x509_authorities,json=x509Authorities,proto3" json:"x509_authorities,omitempty"`
	// jwt_authorities field mask.
	JwtAuthorities bool `protobuf:"varint,3,opt,name=jwt_authorities,json=jwtAuthorities,proto3" json:"jwt_authorities,omitempty"`
	// refresh_hint field mask.
	RefreshHint bool `protobuf:"varint,4,opt,name=refresh_hint,json=refreshHint,proto3" json:"refresh_hint,omitempty"`
	// sequence_number field mask.
	SequenceNumber bool `protobuf:"varint,5,opt,name=sequence_number,json=sequenceNumber,proto3" json:"sequence_number,omitempty"`
	// wit_authorities field mask.
	WitAuthorities bool `protobuf:"varint,6,opt,name=wit_authorities,json=witAuthorities,proto3" json:"wit_authorities,omitempty"`
	unknownFields  protoimpl.UnknownFields
	sizeCache      protoimpl.SizeCache
}

func (x *BundleMask) Reset() {
	*x = BundleMask{}
	mi := &file_spire_api_types_bundle_proto_msgTypes[4]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *BundleMask) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*BundleMask) ProtoMessage() {}

func (x *BundleMask) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_types_bundle_proto_msgTypes[4]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use BundleMask.ProtoReflect.Descriptor instead.
func (*BundleMask) Descriptor() ([]byte, []int) {
	return file_spire_api_types_bundle_proto_rawDescGZIP(), []int{4}
}

func (x *BundleMask) GetX509Authorities() bool {
	if x != nil {
		return x.X509Authorities
	}
	return false
}

func (x *BundleMask) GetJwtAuthorities() bool {
	if x != nil {
		return x.JwtAuthorities
	}
	return false
}

func (x *BundleMask) GetRefreshHint() bool {
	if x != nil {
		return x.RefreshHint
	}
	return false
}

func (x *BundleMask) GetSequenceNumber() bool {
	if x != nil {
		return x.SequenceNumber
	}
	return false
}

func (x *BundleMask) GetWitAuthorities() bool {
	if x != nil {
		return x.WitAuthorities
	}
	return false
}

var File_spire_api_types_bundle_proto protoreflect.FileDescriptor

const file_spire_api_types_bundle_proto_rawDesc = "" +
	"\n" +
	"\x1cspire/api/types/bundle.proto\x12\x0fspire.api.types\"\xc8\x02\n" +
	"\x06Bundle\x12!\n" +
	"\ftrust_domain\x18\x01 \x01(\tR\vtrustDomain\x12K\n" +
	"\x10x509_authorities\x18\x02 \x03(\v2 .spire.api.types.X509CertificateR\x0fx509Authorities\x12@\n" +
	"\x0fjwt_authorities\x18\x03 \x03(\v2\x17.spire.api.types.JWTKeyR\x0ejwtAuthorities\x12!\n" +
	"\frefresh_hint\x18\x04 \x01(\x03R\vrefreshHint\x12'\n" +
	"\x0fsequence_number\x18\x05 \x01(\x04R\x0esequenceNumber\x12@\n" +
	"\x0fwit_authorities\x18\x06 \x03(\v2\x17.spire.api.types.WITKeyR\x0ewitAuthorities\"?\n" +
	"\x0fX509Certificate\x12\x12\n" +
	"\x04asn1\x18\x01 \x01(\fR\x04asn1\x12\x18\n" +
	"\atainted\x18\x02 \x01(\bR\atainted\"w\n" +
	"\x06JWTKey\x12\x1d\n" +
	"\n" +
	"public_key\x18\x01 \x01(\fR\tpublicKey\x12\x15\n" +
	"\x06key_id\x18\x02 \x01(\tR\x05keyId\x12\x1d\n" +
	"\n" +
	"expires_at\x18\x03 \x01(\x03R\texpiresAt\x12\x18\n" +
	"\atainted\x18\x04 \x01(\bR\atainted\"w\n" +
	"\x06WITKey\x12\x1d\n" +
	"\n" +
	"public_key\x18\x01 \x01(\fR\tpublicKey\x12\x15\n" +
	"\x06key_id\x18\x02 \x01(\tR\x05keyId\x12\x1d\n" +
	"\n" +
	"expires_at\x18\x03 \x01(\x03R\texpiresAt\x12\x18\n" +
	"\atainted\x18\x04 \x01(\bR\atainted\"\xd5\x01\n" +
	"\n" +
	"BundleMask\x12)\n" +
	"\x10x509_authorities\x18\x02 \x01(\bR\x0fx509Authorities\x12'\n" +
	"\x0fjwt_authorities\x18\x03 \x01(\bR\x0ejwtAuthorities\x12!\n" +
	"\frefresh_hint\x18\x04 \x01(\bR\vrefreshHint\x12'\n" +
	"\x0fsequence_number\x18\x05 \x01(\bR\x0esequenceNumber\x12'\n" +
	"\x0fwit_authorities\x18\x06 \x01(\bR\x0ewitAuthoritiesB7Z5github.com/spiffe/spire-api-sdk/proto/spire/api/typesb\x06proto3"

var (
	file_spire_api_types_bundle_proto_rawDescOnce sync.Once
	file_spire_api_types_bundle_proto_rawDescData []byte
)

func file_spire_api_types_bundle_proto_rawDescGZIP() []byte {
	file_spire_api_types_bundle_proto_rawDescOnce.Do(func() {
		file_spire_api_types_bundle_proto_rawDescData = protoimpl.X.CompressGZIP(unsafe.Slice(unsafe.StringData(file_spire_api_types_bundle_proto_rawDesc), len(file_spire_api_types_bundle_proto_rawDesc)))
	})
	return file_spire_api_types_bundle_proto_rawDescData
}

var file_spire_api_types_bundle_proto_msgTypes = make([]protoimpl.MessageInfo, 5)
var file_spire_api_types_bundle_proto_goTypes = []any{
	(*Bundle)(nil),          // 0: spire.api.types.Bundle
	(*X509Certificate)(nil), // 1: spire.api.types.X509Certificate
	(*JWTKey)(nil),          // 2: spire.api.types.JWTKey
	(*WITKey)(nil),          // 3: spire.api.types.WITKey
	(*BundleMask)(nil),      // 4: spire.api.types.BundleMask
}
var file_spire_api_types_bundle_proto_depIdxs = []int32{
	1, // 0: spire.api.types.Bundle.x509_authorities:type_name -> spire.api.types.X509Certificate
	2, // 1: spire.api.types.Bundle.jwt_authorities:type_name -> spire.api.types.JWTKey
	3, // 2: spire.api.types.Bundle.wit_authorities:type_name -> spire.api.types.WITKey
	3, // [3:3] is the sub-list for method output_type
	3, // [3:3] is the sub-list for method input_type
	3, // [3:3] is the sub-list for extension type_name
	3, // [3:3] is the sub-list for extension extendee
	0, // [0:3] is the sub-list for field type_name
}

func init() { file_spire_api_types_bundle_proto_init() }
func file_spire_api_types_bundle_proto_init() {
	if File_spire_api_types_bundle_proto != nil {
		return
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: unsafe.Slice(unsafe.StringData(file_spire_api_types_bundle_proto_rawDesc), len(file_spire_api_types_bundle_proto_rawDesc)),
			NumEnums:      0,
			NumMessages:   5,
			NumExtensions: 0,
			NumServices:   0,
		},
		GoTypes:           file_spire_api_types_bundle_proto_goTypes,
		DependencyIndexes: file_spire_api_types_bundle_proto_depIdxs,
		MessageInfos:      file_spire_api_types_bundle_proto_msgTypes,
	}.Build()
	File_spire_api_types_bundle_proto = out.File
	file_spire_api_types_bundle_proto_goTypes = nil
	file_spire_api_types_bundle_proto_depIdxs = nil
}
