// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.36.7
// 	protoc        v6.30.2
// source: spire/api/server/agent/v1/agent.proto

package agentv1

import (
	types "github.com/spiffe/spire-api-sdk/proto/spire/api/types"
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	emptypb "google.golang.org/protobuf/types/known/emptypb"
	wrapperspb "google.golang.org/protobuf/types/known/wrapperspb"
	reflect "reflect"
	sync "sync"
	unsafe "unsafe"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type CountAgentsRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Filters the agents returned by the list operation.
	Filter        *CountAgentsRequest_Filter `protobuf:"bytes,1,opt,name=filter,proto3" json:"filter,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *CountAgentsRequest) Reset() {
	*x = CountAgentsRequest{}
	mi := &file_spire_api_server_agent_v1_agent_proto_msgTypes[0]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *CountAgentsRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*CountAgentsRequest) ProtoMessage() {}

func (x *CountAgentsRequest) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_agent_v1_agent_proto_msgTypes[0]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use CountAgentsRequest.ProtoReflect.Descriptor instead.
func (*CountAgentsRequest) Descriptor() ([]byte, []int) {
	return file_spire_api_server_agent_v1_agent_proto_rawDescGZIP(), []int{0}
}

func (x *CountAgentsRequest) GetFilter() *CountAgentsRequest_Filter {
	if x != nil {
		return x.Filter
	}
	return nil
}

type CountAgentsResponse struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Count         int32                  `protobuf:"varint,1,opt,name=count,proto3" json:"count,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *CountAgentsResponse) Reset() {
	*x = CountAgentsResponse{}
	mi := &file_spire_api_server_agent_v1_agent_proto_msgTypes[1]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *CountAgentsResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*CountAgentsResponse) ProtoMessage() {}

func (x *CountAgentsResponse) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_agent_v1_agent_proto_msgTypes[1]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use CountAgentsResponse.ProtoReflect.Descriptor instead.
func (*CountAgentsResponse) Descriptor() ([]byte, []int) {
	return file_spire_api_server_agent_v1_agent_proto_rawDescGZIP(), []int{1}
}

func (x *CountAgentsResponse) GetCount() int32 {
	if x != nil {
		return x.Count
	}
	return 0
}

type ListAgentsRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Filters the agents returned by the list operation.
	Filter *ListAgentsRequest_Filter `protobuf:"bytes,1,opt,name=filter,proto3" json:"filter,omitempty"`
	// An output mask indicating which agent fields are set in the response.
	OutputMask *types.AgentMask `protobuf:"bytes,2,opt,name=output_mask,json=outputMask,proto3" json:"output_mask,omitempty"`
	// The maximum number of results to return. The server may further
	// constrain this value, or if zero, choose its own.
	PageSize int32 `protobuf:"varint,3,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
	// The next_page_token value returned from a previous request, if any.
	PageToken     string `protobuf:"bytes,4,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ListAgentsRequest) Reset() {
	*x = ListAgentsRequest{}
	mi := &file_spire_api_server_agent_v1_agent_proto_msgTypes[2]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ListAgentsRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ListAgentsRequest) ProtoMessage() {}

func (x *ListAgentsRequest) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_agent_v1_agent_proto_msgTypes[2]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ListAgentsRequest.ProtoReflect.Descriptor instead.
func (*ListAgentsRequest) Descriptor() ([]byte, []int) {
	return file_spire_api_server_agent_v1_agent_proto_rawDescGZIP(), []int{2}
}

func (x *ListAgentsRequest) GetFilter() *ListAgentsRequest_Filter {
	if x != nil {
		return x.Filter
	}
	return nil
}

func (x *ListAgentsRequest) GetOutputMask() *types.AgentMask {
	if x != nil {
		return x.OutputMask
	}
	return nil
}

func (x *ListAgentsRequest) GetPageSize() int32 {
	if x != nil {
		return x.PageSize
	}
	return 0
}

func (x *ListAgentsRequest) GetPageToken() string {
	if x != nil {
		return x.PageToken
	}
	return ""
}

type ListAgentsResponse struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// The agents.
	Agents []*types.Agent `protobuf:"bytes,1,rep,name=agents,proto3" json:"agents,omitempty"`
	// The page token for the next request. Empty if there are no more results.
	// This field should be checked by clients even when a page_size was not
	// requested, since the server may choose its own (see page_size).
	NextPageToken string `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ListAgentsResponse) Reset() {
	*x = ListAgentsResponse{}
	mi := &file_spire_api_server_agent_v1_agent_proto_msgTypes[3]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ListAgentsResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ListAgentsResponse) ProtoMessage() {}

func (x *ListAgentsResponse) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_agent_v1_agent_proto_msgTypes[3]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ListAgentsResponse.ProtoReflect.Descriptor instead.
func (*ListAgentsResponse) Descriptor() ([]byte, []int) {
	return file_spire_api_server_agent_v1_agent_proto_rawDescGZIP(), []int{3}
}

func (x *ListAgentsResponse) GetAgents() []*types.Agent {
	if x != nil {
		return x.Agents
	}
	return nil
}

func (x *ListAgentsResponse) GetNextPageToken() string {
	if x != nil {
		return x.NextPageToken
	}
	return ""
}

type GetAgentRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. The SPIFFE ID of the agent.
	Id *types.SPIFFEID `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// An output mask indicating which agent fields are set in the response.
	OutputMask    *types.AgentMask `protobuf:"bytes,2,opt,name=output_mask,json=outputMask,proto3" json:"output_mask,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetAgentRequest) Reset() {
	*x = GetAgentRequest{}
	mi := &file_spire_api_server_agent_v1_agent_proto_msgTypes[4]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetAgentRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetAgentRequest) ProtoMessage() {}

func (x *GetAgentRequest) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_agent_v1_agent_proto_msgTypes[4]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetAgentRequest.ProtoReflect.Descriptor instead.
func (*GetAgentRequest) Descriptor() ([]byte, []int) {
	return file_spire_api_server_agent_v1_agent_proto_rawDescGZIP(), []int{4}
}

func (x *GetAgentRequest) GetId() *types.SPIFFEID {
	if x != nil {
		return x.Id
	}
	return nil
}

func (x *GetAgentRequest) GetOutputMask() *types.AgentMask {
	if x != nil {
		return x.OutputMask
	}
	return nil
}

type DeleteAgentRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. The SPIFFE ID of the agent.
	Id            *types.SPIFFEID `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *DeleteAgentRequest) Reset() {
	*x = DeleteAgentRequest{}
	mi := &file_spire_api_server_agent_v1_agent_proto_msgTypes[5]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *DeleteAgentRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*DeleteAgentRequest) ProtoMessage() {}

func (x *DeleteAgentRequest) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_agent_v1_agent_proto_msgTypes[5]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use DeleteAgentRequest.ProtoReflect.Descriptor instead.
func (*DeleteAgentRequest) Descriptor() ([]byte, []int) {
	return file_spire_api_server_agent_v1_agent_proto_rawDescGZIP(), []int{5}
}

func (x *DeleteAgentRequest) GetId() *types.SPIFFEID {
	if x != nil {
		return x.Id
	}
	return nil
}

type BanAgentRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. The SPIFFE ID of the agent.
	Id            *types.SPIFFEID `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *BanAgentRequest) Reset() {
	*x = BanAgentRequest{}
	mi := &file_spire_api_server_agent_v1_agent_proto_msgTypes[6]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *BanAgentRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*BanAgentRequest) ProtoMessage() {}

func (x *BanAgentRequest) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_agent_v1_agent_proto_msgTypes[6]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use BanAgentRequest.ProtoReflect.Descriptor instead.
func (*BanAgentRequest) Descriptor() ([]byte, []int) {
	return file_spire_api_server_agent_v1_agent_proto_rawDescGZIP(), []int{6}
}

func (x *BanAgentRequest) GetId() *types.SPIFFEID {
	if x != nil {
		return x.Id
	}
	return nil
}

type AttestAgentRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. The data for the step in the attestation flow.
	//
	// Types that are valid to be assigned to Step:
	//
	//	*AttestAgentRequest_Params_
	//	*AttestAgentRequest_ChallengeResponse
	Step          isAttestAgentRequest_Step `protobuf_oneof:"step"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *AttestAgentRequest) Reset() {
	*x = AttestAgentRequest{}
	mi := &file_spire_api_server_agent_v1_agent_proto_msgTypes[7]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *AttestAgentRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*AttestAgentRequest) ProtoMessage() {}

func (x *AttestAgentRequest) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_agent_v1_agent_proto_msgTypes[7]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use AttestAgentRequest.ProtoReflect.Descriptor instead.
func (*AttestAgentRequest) Descriptor() ([]byte, []int) {
	return file_spire_api_server_agent_v1_agent_proto_rawDescGZIP(), []int{7}
}

func (x *AttestAgentRequest) GetStep() isAttestAgentRequest_Step {
	if x != nil {
		return x.Step
	}
	return nil
}

func (x *AttestAgentRequest) GetParams() *AttestAgentRequest_Params {
	if x != nil {
		if x, ok := x.Step.(*AttestAgentRequest_Params_); ok {
			return x.Params
		}
	}
	return nil
}

func (x *AttestAgentRequest) GetChallengeResponse() []byte {
	if x != nil {
		if x, ok := x.Step.(*AttestAgentRequest_ChallengeResponse); ok {
			return x.ChallengeResponse
		}
	}
	return nil
}

type isAttestAgentRequest_Step interface {
	isAttestAgentRequest_Step()
}

type AttestAgentRequest_Params_ struct {
	// Attestation parameters. These are only sent in the initial request.
	Params *AttestAgentRequest_Params `protobuf:"bytes,1,opt,name=params,proto3,oneof"`
}

type AttestAgentRequest_ChallengeResponse struct {
	// The response to a challenge issued by the attestor. Only sent in
	// response to a challenge received by the issuer.
	ChallengeResponse []byte `protobuf:"bytes,2,opt,name=challenge_response,json=challengeResponse,proto3,oneof"`
}

func (*AttestAgentRequest_Params_) isAttestAgentRequest_Step() {}

func (*AttestAgentRequest_ChallengeResponse) isAttestAgentRequest_Step() {}

type AttestAgentResponse struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Types that are valid to be assigned to Step:
	//
	//	*AttestAgentResponse_Result_
	//	*AttestAgentResponse_Challenge
	Step          isAttestAgentResponse_Step `protobuf_oneof:"step"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *AttestAgentResponse) Reset() {
	*x = AttestAgentResponse{}
	mi := &file_spire_api_server_agent_v1_agent_proto_msgTypes[8]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *AttestAgentResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*AttestAgentResponse) ProtoMessage() {}

func (x *AttestAgentResponse) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_agent_v1_agent_proto_msgTypes[8]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use AttestAgentResponse.ProtoReflect.Descriptor instead.
func (*AttestAgentResponse) Descriptor() ([]byte, []int) {
	return file_spire_api_server_agent_v1_agent_proto_rawDescGZIP(), []int{8}
}

func (x *AttestAgentResponse) GetStep() isAttestAgentResponse_Step {
	if x != nil {
		return x.Step
	}
	return nil
}

func (x *AttestAgentResponse) GetResult() *AttestAgentResponse_Result {
	if x != nil {
		if x, ok := x.Step.(*AttestAgentResponse_Result_); ok {
			return x.Result
		}
	}
	return nil
}

func (x *AttestAgentResponse) GetChallenge() []byte {
	if x != nil {
		if x, ok := x.Step.(*AttestAgentResponse_Challenge); ok {
			return x.Challenge
		}
	}
	return nil
}

type isAttestAgentResponse_Step interface {
	isAttestAgentResponse_Step()
}

type AttestAgentResponse_Result_ struct {
	// Attestation results. If set, attestation has completed.
	Result *AttestAgentResponse_Result `protobuf:"bytes,1,opt,name=result,proto3,oneof"`
}

type AttestAgentResponse_Challenge struct {
	// A challenge issued by the attestor. If set, the caller is expected
	// to send another request on the stream with the challenge response.
	Challenge []byte `protobuf:"bytes,2,opt,name=challenge,proto3,oneof"`
}

func (*AttestAgentResponse_Result_) isAttestAgentResponse_Step() {}

func (*AttestAgentResponse_Challenge) isAttestAgentResponse_Step() {}

type RenewAgentRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. Parameters for the X509-SVID.
	Params        *AgentX509SVIDParams `protobuf:"bytes,1,opt,name=params,proto3" json:"params,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *RenewAgentRequest) Reset() {
	*x = RenewAgentRequest{}
	mi := &file_spire_api_server_agent_v1_agent_proto_msgTypes[9]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *RenewAgentRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*RenewAgentRequest) ProtoMessage() {}

func (x *RenewAgentRequest) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_agent_v1_agent_proto_msgTypes[9]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use RenewAgentRequest.ProtoReflect.Descriptor instead.
func (*RenewAgentRequest) Descriptor() ([]byte, []int) {
	return file_spire_api_server_agent_v1_agent_proto_rawDescGZIP(), []int{9}
}

func (x *RenewAgentRequest) GetParams() *AgentX509SVIDParams {
	if x != nil {
		return x.Params
	}
	return nil
}

type RenewAgentResponse struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// The renewed X509-SVID
	Svid          *types.X509SVID `protobuf:"bytes,1,opt,name=svid,proto3" json:"svid,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *RenewAgentResponse) Reset() {
	*x = RenewAgentResponse{}
	mi := &file_spire_api_server_agent_v1_agent_proto_msgTypes[10]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *RenewAgentResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*RenewAgentResponse) ProtoMessage() {}

func (x *RenewAgentResponse) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_agent_v1_agent_proto_msgTypes[10]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use RenewAgentResponse.ProtoReflect.Descriptor instead.
func (*RenewAgentResponse) Descriptor() ([]byte, []int) {
	return file_spire_api_server_agent_v1_agent_proto_rawDescGZIP(), []int{10}
}

func (x *RenewAgentResponse) GetSvid() *types.X509SVID {
	if x != nil {
		return x.Svid
	}
	return nil
}

type CreateJoinTokenRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. How long until the token expires (in seconds).
	Ttl int32 `protobuf:"varint,1,opt,name=ttl,proto3" json:"ttl,omitempty"`
	// An optional token value to use for the token. Must be unique. If unset,
	// the server will generate a value.
	Token string `protobuf:"bytes,2,opt,name=token,proto3" json:"token,omitempty"`
	// An optional SPIFFE ID to assign to the agent beyond that given by
	// join token attestation. If set, this results in an entry being created
	// that maps the attestation assigned agent ID to this ID.
	AgentId       *types.SPIFFEID `protobuf:"bytes,3,opt,name=agent_id,json=agentId,proto3" json:"agent_id,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *CreateJoinTokenRequest) Reset() {
	*x = CreateJoinTokenRequest{}
	mi := &file_spire_api_server_agent_v1_agent_proto_msgTypes[11]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *CreateJoinTokenRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*CreateJoinTokenRequest) ProtoMessage() {}

func (x *CreateJoinTokenRequest) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_agent_v1_agent_proto_msgTypes[11]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use CreateJoinTokenRequest.ProtoReflect.Descriptor instead.
func (*CreateJoinTokenRequest) Descriptor() ([]byte, []int) {
	return file_spire_api_server_agent_v1_agent_proto_rawDescGZIP(), []int{11}
}

func (x *CreateJoinTokenRequest) GetTtl() int32 {
	if x != nil {
		return x.Ttl
	}
	return 0
}

func (x *CreateJoinTokenRequest) GetToken() string {
	if x != nil {
		return x.Token
	}
	return ""
}

func (x *CreateJoinTokenRequest) GetAgentId() *types.SPIFFEID {
	if x != nil {
		return x.AgentId
	}
	return nil
}

type AgentX509SVIDParams struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. The ASN.1 DER encoded Certificate Signing Request (CSR). The
	// CSR is only used to convey the public key; other fields in the CSR are
	// ignored. The agent X509-SVID attributes are determined by the server.
	Csr           []byte `protobuf:"bytes,1,opt,name=csr,proto3" json:"csr,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *AgentX509SVIDParams) Reset() {
	*x = AgentX509SVIDParams{}
	mi := &file_spire_api_server_agent_v1_agent_proto_msgTypes[12]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *AgentX509SVIDParams) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*AgentX509SVIDParams) ProtoMessage() {}

func (x *AgentX509SVIDParams) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_agent_v1_agent_proto_msgTypes[12]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use AgentX509SVIDParams.ProtoReflect.Descriptor instead.
func (*AgentX509SVIDParams) Descriptor() ([]byte, []int) {
	return file_spire_api_server_agent_v1_agent_proto_rawDescGZIP(), []int{12}
}

func (x *AgentX509SVIDParams) GetCsr() []byte {
	if x != nil {
		return x.Csr
	}
	return nil
}

type PostStatusRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. Serial number of the bundle currently being served by the agent
	CurrentBundleSerial uint64 `protobuf:"varint,1,opt,name=current_bundle_serial,json=currentBundleSerial,proto3" json:"current_bundle_serial,omitempty"`
	// Optional. The version of the agent.
	AgentVersion  string `protobuf:"bytes,2,opt,name=agent_version,json=agentVersion,proto3" json:"agent_version,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *PostStatusRequest) Reset() {
	*x = PostStatusRequest{}
	mi := &file_spire_api_server_agent_v1_agent_proto_msgTypes[13]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *PostStatusRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*PostStatusRequest) ProtoMessage() {}

func (x *PostStatusRequest) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_agent_v1_agent_proto_msgTypes[13]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use PostStatusRequest.ProtoReflect.Descriptor instead.
func (*PostStatusRequest) Descriptor() ([]byte, []int) {
	return file_spire_api_server_agent_v1_agent_proto_rawDescGZIP(), []int{13}
}

func (x *PostStatusRequest) GetCurrentBundleSerial() uint64 {
	if x != nil {
		return x.CurrentBundleSerial
	}
	return 0
}

func (x *PostStatusRequest) GetAgentVersion() string {
	if x != nil {
		return x.AgentVersion
	}
	return ""
}

type PostStatusResponse struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *PostStatusResponse) Reset() {
	*x = PostStatusResponse{}
	mi := &file_spire_api_server_agent_v1_agent_proto_msgTypes[14]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *PostStatusResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*PostStatusResponse) ProtoMessage() {}

func (x *PostStatusResponse) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_agent_v1_agent_proto_msgTypes[14]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use PostStatusResponse.ProtoReflect.Descriptor instead.
func (*PostStatusResponse) Descriptor() ([]byte, []int) {
	return file_spire_api_server_agent_v1_agent_proto_rawDescGZIP(), []int{14}
}

type CountAgentsRequest_Filter struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Filters agents to those matching the attestation type.
	ByAttestationType string `protobuf:"bytes,1,opt,name=by_attestation_type,json=byAttestationType,proto3" json:"by_attestation_type,omitempty"`
	// Filters agents to those satisfying the selector match.
	BySelectorMatch *types.SelectorMatch `protobuf:"bytes,2,opt,name=by_selector_match,json=bySelectorMatch,proto3" json:"by_selector_match,omitempty"`
	// Filters agents to those that are banned.
	ByBanned *wrapperspb.BoolValue `protobuf:"bytes,3,opt,name=by_banned,json=byBanned,proto3" json:"by_banned,omitempty"`
	// Filters agents that can re-attest.
	ByCanReattest *wrapperspb.BoolValue `protobuf:"bytes,4,opt,name=by_can_reattest,json=byCanReattest,proto3" json:"by_can_reattest,omitempty"`
	// Filters agents by those expires before.
	ByExpiresBefore string `protobuf:"bytes,5,opt,name=by_expires_before,json=byExpiresBefore,proto3" json:"by_expires_before,omitempty"`
	unknownFields   protoimpl.UnknownFields
	sizeCache       protoimpl.SizeCache
}

func (x *CountAgentsRequest_Filter) Reset() {
	*x = CountAgentsRequest_Filter{}
	mi := &file_spire_api_server_agent_v1_agent_proto_msgTypes[15]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *CountAgentsRequest_Filter) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*CountAgentsRequest_Filter) ProtoMessage() {}

func (x *CountAgentsRequest_Filter) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_agent_v1_agent_proto_msgTypes[15]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use CountAgentsRequest_Filter.ProtoReflect.Descriptor instead.
func (*CountAgentsRequest_Filter) Descriptor() ([]byte, []int) {
	return file_spire_api_server_agent_v1_agent_proto_rawDescGZIP(), []int{0, 0}
}

func (x *CountAgentsRequest_Filter) GetByAttestationType() string {
	if x != nil {
		return x.ByAttestationType
	}
	return ""
}

func (x *CountAgentsRequest_Filter) GetBySelectorMatch() *types.SelectorMatch {
	if x != nil {
		return x.BySelectorMatch
	}
	return nil
}

func (x *CountAgentsRequest_Filter) GetByBanned() *wrapperspb.BoolValue {
	if x != nil {
		return x.ByBanned
	}
	return nil
}

func (x *CountAgentsRequest_Filter) GetByCanReattest() *wrapperspb.BoolValue {
	if x != nil {
		return x.ByCanReattest
	}
	return nil
}

func (x *CountAgentsRequest_Filter) GetByExpiresBefore() string {
	if x != nil {
		return x.ByExpiresBefore
	}
	return ""
}

type ListAgentsRequest_Filter struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Filters agents to those matching the attestation type.
	ByAttestationType string `protobuf:"bytes,1,opt,name=by_attestation_type,json=byAttestationType,proto3" json:"by_attestation_type,omitempty"`
	// Filters agents to those satisfying the selector match.
	BySelectorMatch *types.SelectorMatch `protobuf:"bytes,2,opt,name=by_selector_match,json=bySelectorMatch,proto3" json:"by_selector_match,omitempty"`
	// Filters agents to those that are banned.
	ByBanned *wrapperspb.BoolValue `protobuf:"bytes,3,opt,name=by_banned,json=byBanned,proto3" json:"by_banned,omitempty"`
	// Filters agents that can re-attest.
	ByCanReattest *wrapperspb.BoolValue `protobuf:"bytes,4,opt,name=by_can_reattest,json=byCanReattest,proto3" json:"by_can_reattest,omitempty"`
	// Filters agents by those expires before.
	ByExpiresBefore string `protobuf:"bytes,5,opt,name=by_expires_before,json=byExpiresBefore,proto3" json:"by_expires_before,omitempty"`
	unknownFields   protoimpl.UnknownFields
	sizeCache       protoimpl.SizeCache
}

func (x *ListAgentsRequest_Filter) Reset() {
	*x = ListAgentsRequest_Filter{}
	mi := &file_spire_api_server_agent_v1_agent_proto_msgTypes[16]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ListAgentsRequest_Filter) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ListAgentsRequest_Filter) ProtoMessage() {}

func (x *ListAgentsRequest_Filter) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_agent_v1_agent_proto_msgTypes[16]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ListAgentsRequest_Filter.ProtoReflect.Descriptor instead.
func (*ListAgentsRequest_Filter) Descriptor() ([]byte, []int) {
	return file_spire_api_server_agent_v1_agent_proto_rawDescGZIP(), []int{2, 0}
}

func (x *ListAgentsRequest_Filter) GetByAttestationType() string {
	if x != nil {
		return x.ByAttestationType
	}
	return ""
}

func (x *ListAgentsRequest_Filter) GetBySelectorMatch() *types.SelectorMatch {
	if x != nil {
		return x.BySelectorMatch
	}
	return nil
}

func (x *ListAgentsRequest_Filter) GetByBanned() *wrapperspb.BoolValue {
	if x != nil {
		return x.ByBanned
	}
	return nil
}

func (x *ListAgentsRequest_Filter) GetByCanReattest() *wrapperspb.BoolValue {
	if x != nil {
		return x.ByCanReattest
	}
	return nil
}

func (x *ListAgentsRequest_Filter) GetByExpiresBefore() string {
	if x != nil {
		return x.ByExpiresBefore
	}
	return ""
}

type AttestAgentRequest_Params struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. The attestation data.
	Data *types.AttestationData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// Required. The X509-SVID parameters.
	Params        *AgentX509SVIDParams `protobuf:"bytes,2,opt,name=params,proto3" json:"params,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *AttestAgentRequest_Params) Reset() {
	*x = AttestAgentRequest_Params{}
	mi := &file_spire_api_server_agent_v1_agent_proto_msgTypes[17]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *AttestAgentRequest_Params) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*AttestAgentRequest_Params) ProtoMessage() {}

func (x *AttestAgentRequest_Params) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_agent_v1_agent_proto_msgTypes[17]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use AttestAgentRequest_Params.ProtoReflect.Descriptor instead.
func (*AttestAgentRequest_Params) Descriptor() ([]byte, []int) {
	return file_spire_api_server_agent_v1_agent_proto_rawDescGZIP(), []int{7, 0}
}

func (x *AttestAgentRequest_Params) GetData() *types.AttestationData {
	if x != nil {
		return x.Data
	}
	return nil
}

func (x *AttestAgentRequest_Params) GetParams() *AgentX509SVIDParams {
	if x != nil {
		return x.Params
	}
	return nil
}

type AttestAgentResponse_Result struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// The agent X509-SVID.
	Svid *types.X509SVID `protobuf:"bytes,1,opt,name=svid,proto3" json:"svid,omitempty"`
	// Whether or not the attested agent can reattest to renew its X509-SVID
	Reattestable  bool `protobuf:"varint,2,opt,name=reattestable,proto3" json:"reattestable,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *AttestAgentResponse_Result) Reset() {
	*x = AttestAgentResponse_Result{}
	mi := &file_spire_api_server_agent_v1_agent_proto_msgTypes[18]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *AttestAgentResponse_Result) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*AttestAgentResponse_Result) ProtoMessage() {}

func (x *AttestAgentResponse_Result) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_agent_v1_agent_proto_msgTypes[18]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use AttestAgentResponse_Result.ProtoReflect.Descriptor instead.
func (*AttestAgentResponse_Result) Descriptor() ([]byte, []int) {
	return file_spire_api_server_agent_v1_agent_proto_rawDescGZIP(), []int{8, 0}
}

func (x *AttestAgentResponse_Result) GetSvid() *types.X509SVID {
	if x != nil {
		return x.Svid
	}
	return nil
}

func (x *AttestAgentResponse_Result) GetReattestable() bool {
	if x != nil {
		return x.Reattestable
	}
	return false
}

var File_spire_api_server_agent_v1_agent_proto protoreflect.FileDescriptor

const file_spire_api_server_agent_v1_agent_proto_rawDesc = "" +
	"\n" +
	"%spire/api/server/agent/v1/agent.proto\x12\x19spire.api.server.agent.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1bspire/api/types/agent.proto\x1a!spire/api/types/attestation.proto\x1a\x1fspire/api/types/jointoken.proto\x1a\x1espire/api/types/selector.proto\x1a\x1espire/api/types/spiffeid.proto\x1a\x1espire/api/types/x509svid.proto\"\x92\x03\n" +
	"\x12CountAgentsRequest\x12L\n" +
	"\x06filter\x18\x01 \x01(\v24.spire.api.server.agent.v1.CountAgentsRequest.FilterR\x06filter\x1a\xad\x02\n" +
	"\x06Filter\x12.\n" +
	"\x13by_attestation_type\x18\x01 \x01(\tR\x11byAttestationType\x12J\n" +
	"\x11by_selector_match\x18\x02 \x01(\v2\x1e.spire.api.types.SelectorMatchR\x0fbySelectorMatch\x127\n" +
	"\tby_banned\x18\x03 \x01(\v2\x1a.google.protobuf.BoolValueR\bbyBanned\x12B\n" +
	"\x0fby_can_reattest\x18\x04 \x01(\v2\x1a.google.protobuf.BoolValueR\rbyCanReattest\x12*\n" +
	"\x11by_expires_before\x18\x05 \x01(\tR\x0fbyExpiresBefore\"+\n" +
	"\x13CountAgentsResponse\x12\x14\n" +
	"\x05count\x18\x01 \x01(\x05R\x05count\"\x89\x04\n" +
	"\x11ListAgentsRequest\x12K\n" +
	"\x06filter\x18\x01 \x01(\v23.spire.api.server.agent.v1.ListAgentsRequest.FilterR\x06filter\x12;\n" +
	"\voutput_mask\x18\x02 \x01(\v2\x1a.spire.api.types.AgentMaskR\n" +
	"outputMask\x12\x1b\n" +
	"\tpage_size\x18\x03 \x01(\x05R\bpageSize\x12\x1d\n" +
	"\n" +
	"page_token\x18\x04 \x01(\tR\tpageToken\x1a\xad\x02\n" +
	"\x06Filter\x12.\n" +
	"\x13by_attestation_type\x18\x01 \x01(\tR\x11byAttestationType\x12J\n" +
	"\x11by_selector_match\x18\x02 \x01(\v2\x1e.spire.api.types.SelectorMatchR\x0fbySelectorMatch\x127\n" +
	"\tby_banned\x18\x03 \x01(\v2\x1a.google.protobuf.BoolValueR\bbyBanned\x12B\n" +
	"\x0fby_can_reattest\x18\x04 \x01(\v2\x1a.google.protobuf.BoolValueR\rbyCanReattest\x12*\n" +
	"\x11by_expires_before\x18\x05 \x01(\tR\x0fbyExpiresBefore\"l\n" +
	"\x12ListAgentsResponse\x12.\n" +
	"\x06agents\x18\x01 \x03(\v2\x16.spire.api.types.AgentR\x06agents\x12&\n" +
	"\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"y\n" +
	"\x0fGetAgentRequest\x12)\n" +
	"\x02id\x18\x01 \x01(\v2\x19.spire.api.types.SPIFFEIDR\x02id\x12;\n" +
	"\voutput_mask\x18\x02 \x01(\v2\x1a.spire.api.types.AgentMaskR\n" +
	"outputMask\"?\n" +
	"\x12DeleteAgentRequest\x12)\n" +
	"\x02id\x18\x01 \x01(\v2\x19.spire.api.types.SPIFFEIDR\x02id\"<\n" +
	"\x0fBanAgentRequest\x12)\n" +
	"\x02id\x18\x01 \x01(\v2\x19.spire.api.types.SPIFFEIDR\x02id\"\xa6\x02\n" +
	"\x12AttestAgentRequest\x12N\n" +
	"\x06params\x18\x01 \x01(\v24.spire.api.server.agent.v1.AttestAgentRequest.ParamsH\x00R\x06params\x12/\n" +
	"\x12challenge_response\x18\x02 \x01(\fH\x00R\x11challengeResponse\x1a\x86\x01\n" +
	"\x06Params\x124\n" +
	"\x04data\x18\x01 \x01(\v2 .spire.api.types.AttestationDataR\x04data\x12F\n" +
	"\x06params\x18\x02 \x01(\v2..spire.api.server.agent.v1.AgentX509SVIDParamsR\x06paramsB\x06\n" +
	"\x04step\"\xeb\x01\n" +
	"\x13AttestAgentResponse\x12O\n" +
	"\x06result\x18\x01 \x01(\v25.spire.api.server.agent.v1.AttestAgentResponse.ResultH\x00R\x06result\x12\x1e\n" +
	"\tchallenge\x18\x02 \x01(\fH\x00R\tchallenge\x1a[\n" +
	"\x06Result\x12-\n" +
	"\x04svid\x18\x01 \x01(\v2\x19.spire.api.types.X509SVIDR\x04svid\x12\"\n" +
	"\freattestable\x18\x02 \x01(\bR\freattestableB\x06\n" +
	"\x04step\"[\n" +
	"\x11RenewAgentRequest\x12F\n" +
	"\x06params\x18\x01 \x01(\v2..spire.api.server.agent.v1.AgentX509SVIDParamsR\x06params\"C\n" +
	"\x12RenewAgentResponse\x12-\n" +
	"\x04svid\x18\x01 \x01(\v2\x19.spire.api.types.X509SVIDR\x04svid\"v\n" +
	"\x16CreateJoinTokenRequest\x12\x10\n" +
	"\x03ttl\x18\x01 \x01(\x05R\x03ttl\x12\x14\n" +
	"\x05token\x18\x02 \x01(\tR\x05token\x124\n" +
	"\bagent_id\x18\x03 \x01(\v2\x19.spire.api.types.SPIFFEIDR\aagentId\"'\n" +
	"\x13AgentX509SVIDParams\x12\x10\n" +
	"\x03csr\x18\x01 \x01(\fR\x03csr\"l\n" +
	"\x11PostStatusRequest\x122\n" +
	"\x15current_bundle_serial\x18\x01 \x01(\x04R\x13currentBundleSerial\x12#\n" +
	"\ragent_version\x18\x02 \x01(\tR\fagentVersion\"\x14\n" +
	"\x12PostStatusResponse2\x80\a\n" +
	"\x05Agent\x12l\n" +
	"\vCountAgents\x12-.spire.api.server.agent.v1.CountAgentsRequest\x1a..spire.api.server.agent.v1.CountAgentsResponse\x12i\n" +
	"\n" +
	"ListAgents\x12,.spire.api.server.agent.v1.ListAgentsRequest\x1a-.spire.api.server.agent.v1.ListAgentsResponse\x12N\n" +
	"\bGetAgent\x12*.spire.api.server.agent.v1.GetAgentRequest\x1a\x16.spire.api.types.Agent\x12T\n" +
	"\vDeleteAgent\x12-.spire.api.server.agent.v1.DeleteAgentRequest\x1a\x16.google.protobuf.Empty\x12N\n" +
	"\bBanAgent\x12*.spire.api.server.agent.v1.BanAgentRequest\x1a\x16.google.protobuf.Empty\x12p\n" +
	"\vAttestAgent\x12-.spire.api.server.agent.v1.AttestAgentRequest\x1a..spire.api.server.agent.v1.AttestAgentResponse(\x010\x01\x12i\n" +
	"\n" +
	"RenewAgent\x12,.spire.api.server.agent.v1.RenewAgentRequest\x1a-.spire.api.server.agent.v1.RenewAgentResponse\x12`\n" +
	"\x0fCreateJoinToken\x121.spire.api.server.agent.v1.CreateJoinTokenRequest\x1a\x1a.spire.api.types.JoinToken\x12i\n" +
	"\n" +
	"PostStatus\x12,.spire.api.server.agent.v1.PostStatusRequest\x1a-.spire.api.server.agent.v1.PostStatusResponseBIZGgithub.com/spiffe/spire-api-sdk/proto/spire/api/server/agent/v1;agentv1b\x06proto3"

var (
	file_spire_api_server_agent_v1_agent_proto_rawDescOnce sync.Once
	file_spire_api_server_agent_v1_agent_proto_rawDescData []byte
)

func file_spire_api_server_agent_v1_agent_proto_rawDescGZIP() []byte {
	file_spire_api_server_agent_v1_agent_proto_rawDescOnce.Do(func() {
		file_spire_api_server_agent_v1_agent_proto_rawDescData = protoimpl.X.CompressGZIP(unsafe.Slice(unsafe.StringData(file_spire_api_server_agent_v1_agent_proto_rawDesc), len(file_spire_api_server_agent_v1_agent_proto_rawDesc)))
	})
	return file_spire_api_server_agent_v1_agent_proto_rawDescData
}

var file_spire_api_server_agent_v1_agent_proto_msgTypes = make([]protoimpl.MessageInfo, 19)
var file_spire_api_server_agent_v1_agent_proto_goTypes = []any{
	(*CountAgentsRequest)(nil),         // 0: spire.api.server.agent.v1.CountAgentsRequest
	(*CountAgentsResponse)(nil),        // 1: spire.api.server.agent.v1.CountAgentsResponse
	(*ListAgentsRequest)(nil),          // 2: spire.api.server.agent.v1.ListAgentsRequest
	(*ListAgentsResponse)(nil),         // 3: spire.api.server.agent.v1.ListAgentsResponse
	(*GetAgentRequest)(nil),            // 4: spire.api.server.agent.v1.GetAgentRequest
	(*DeleteAgentRequest)(nil),         // 5: spire.api.server.agent.v1.DeleteAgentRequest
	(*BanAgentRequest)(nil),            // 6: spire.api.server.agent.v1.BanAgentRequest
	(*AttestAgentRequest)(nil),         // 7: spire.api.server.agent.v1.AttestAgentRequest
	(*AttestAgentResponse)(nil),        // 8: spire.api.server.agent.v1.AttestAgentResponse
	(*RenewAgentRequest)(nil),          // 9: spire.api.server.agent.v1.RenewAgentRequest
	(*RenewAgentResponse)(nil),         // 10: spire.api.server.agent.v1.RenewAgentResponse
	(*CreateJoinTokenRequest)(nil),     // 11: spire.api.server.agent.v1.CreateJoinTokenRequest
	(*AgentX509SVIDParams)(nil),        // 12: spire.api.server.agent.v1.AgentX509SVIDParams
	(*PostStatusRequest)(nil),          // 13: spire.api.server.agent.v1.PostStatusRequest
	(*PostStatusResponse)(nil),         // 14: spire.api.server.agent.v1.PostStatusResponse
	(*CountAgentsRequest_Filter)(nil),  // 15: spire.api.server.agent.v1.CountAgentsRequest.Filter
	(*ListAgentsRequest_Filter)(nil),   // 16: spire.api.server.agent.v1.ListAgentsRequest.Filter
	(*AttestAgentRequest_Params)(nil),  // 17: spire.api.server.agent.v1.AttestAgentRequest.Params
	(*AttestAgentResponse_Result)(nil), // 18: spire.api.server.agent.v1.AttestAgentResponse.Result
	(*types.AgentMask)(nil),            // 19: spire.api.types.AgentMask
	(*types.Agent)(nil),                // 20: spire.api.types.Agent
	(*types.SPIFFEID)(nil),             // 21: spire.api.types.SPIFFEID
	(*types.X509SVID)(nil),             // 22: spire.api.types.X509SVID
	(*types.SelectorMatch)(nil),        // 23: spire.api.types.SelectorMatch
	(*wrapperspb.BoolValue)(nil),       // 24: google.protobuf.BoolValue
	(*types.AttestationData)(nil),      // 25: spire.api.types.AttestationData
	(*emptypb.Empty)(nil),              // 26: google.protobuf.Empty
	(*types.JoinToken)(nil),            // 27: spire.api.types.JoinToken
}
var file_spire_api_server_agent_v1_agent_proto_depIdxs = []int32{
	15, // 0: spire.api.server.agent.v1.CountAgentsRequest.filter:type_name -> spire.api.server.agent.v1.CountAgentsRequest.Filter
	16, // 1: spire.api.server.agent.v1.ListAgentsRequest.filter:type_name -> spire.api.server.agent.v1.ListAgentsRequest.Filter
	19, // 2: spire.api.server.agent.v1.ListAgentsRequest.output_mask:type_name -> spire.api.types.AgentMask
	20, // 3: spire.api.server.agent.v1.ListAgentsResponse.agents:type_name -> spire.api.types.Agent
	21, // 4: spire.api.server.agent.v1.GetAgentRequest.id:type_name -> spire.api.types.SPIFFEID
	19, // 5: spire.api.server.agent.v1.GetAgentRequest.output_mask:type_name -> spire.api.types.AgentMask
	21, // 6: spire.api.server.agent.v1.DeleteAgentRequest.id:type_name -> spire.api.types.SPIFFEID
	21, // 7: spire.api.server.agent.v1.BanAgentRequest.id:type_name -> spire.api.types.SPIFFEID
	17, // 8: spire.api.server.agent.v1.AttestAgentRequest.params:type_name -> spire.api.server.agent.v1.AttestAgentRequest.Params
	18, // 9: spire.api.server.agent.v1.AttestAgentResponse.result:type_name -> spire.api.server.agent.v1.AttestAgentResponse.Result
	12, // 10: spire.api.server.agent.v1.RenewAgentRequest.params:type_name -> spire.api.server.agent.v1.AgentX509SVIDParams
	22, // 11: spire.api.server.agent.v1.RenewAgentResponse.svid:type_name -> spire.api.types.X509SVID
	21, // 12: spire.api.server.agent.v1.CreateJoinTokenRequest.agent_id:type_name -> spire.api.types.SPIFFEID
	23, // 13: spire.api.server.agent.v1.CountAgentsRequest.Filter.by_selector_match:type_name -> spire.api.types.SelectorMatch
	24, // 14: spire.api.server.agent.v1.CountAgentsRequest.Filter.by_banned:type_name -> google.protobuf.BoolValue
	24, // 15: spire.api.server.agent.v1.CountAgentsRequest.Filter.by_can_reattest:type_name -> google.protobuf.BoolValue
	23, // 16: spire.api.server.agent.v1.ListAgentsRequest.Filter.by_selector_match:type_name -> spire.api.types.SelectorMatch
	24, // 17: spire.api.server.agent.v1.ListAgentsRequest.Filter.by_banned:type_name -> google.protobuf.BoolValue
	24, // 18: spire.api.server.agent.v1.ListAgentsRequest.Filter.by_can_reattest:type_name -> google.protobuf.BoolValue
	25, // 19: spire.api.server.agent.v1.AttestAgentRequest.Params.data:type_name -> spire.api.types.AttestationData
	12, // 20: spire.api.server.agent.v1.AttestAgentRequest.Params.params:type_name -> spire.api.server.agent.v1.AgentX509SVIDParams
	22, // 21: spire.api.server.agent.v1.AttestAgentResponse.Result.svid:type_name -> spire.api.types.X509SVID
	0,  // 22: spire.api.server.agent.v1.Agent.CountAgents:input_type -> spire.api.server.agent.v1.CountAgentsRequest
	2,  // 23: spire.api.server.agent.v1.Agent.ListAgents:input_type -> spire.api.server.agent.v1.ListAgentsRequest
	4,  // 24: spire.api.server.agent.v1.Agent.GetAgent:input_type -> spire.api.server.agent.v1.GetAgentRequest
	5,  // 25: spire.api.server.agent.v1.Agent.DeleteAgent:input_type -> spire.api.server.agent.v1.DeleteAgentRequest
	6,  // 26: spire.api.server.agent.v1.Agent.BanAgent:input_type -> spire.api.server.agent.v1.BanAgentRequest
	7,  // 27: spire.api.server.agent.v1.Agent.AttestAgent:input_type -> spire.api.server.agent.v1.AttestAgentRequest
	9,  // 28: spire.api.server.agent.v1.Agent.RenewAgent:input_type -> spire.api.server.agent.v1.RenewAgentRequest
	11, // 29: spire.api.server.agent.v1.Agent.CreateJoinToken:input_type -> spire.api.server.agent.v1.CreateJoinTokenRequest
	13, // 30: spire.api.server.agent.v1.Agent.PostStatus:input_type -> spire.api.server.agent.v1.PostStatusRequest
	1,  // 31: spire.api.server.agent.v1.Agent.CountAgents:output_type -> spire.api.server.agent.v1.CountAgentsResponse
	3,  // 32: spire.api.server.agent.v1.Agent.ListAgents:output_type -> spire.api.server.agent.v1.ListAgentsResponse
	20, // 33: spire.api.server.agent.v1.Agent.GetAgent:output_type -> spire.api.types.Agent
	26, // 34: spire.api.server.agent.v1.Agent.DeleteAgent:output_type -> google.protobuf.Empty
	26, // 35: spire.api.server.agent.v1.Agent.BanAgent:output_type -> google.protobuf.Empty
	8,  // 36: spire.api.server.agent.v1.Agent.AttestAgent:output_type -> spire.api.server.agent.v1.AttestAgentResponse
	10, // 37: spire.api.server.agent.v1.Agent.RenewAgent:output_type -> spire.api.server.agent.v1.RenewAgentResponse
	27, // 38: spire.api.server.agent.v1.Agent.CreateJoinToken:output_type -> spire.api.types.JoinToken
	14, // 39: spire.api.server.agent.v1.Agent.PostStatus:output_type -> spire.api.server.agent.v1.PostStatusResponse
	31, // [31:40] is the sub-list for method output_type
	22, // [22:31] is the sub-list for method input_type
	22, // [22:22] is the sub-list for extension type_name
	22, // [22:22] is the sub-list for extension extendee
	0,  // [0:22] is the sub-list for field type_name
}

func init() { file_spire_api_server_agent_v1_agent_proto_init() }
func file_spire_api_server_agent_v1_agent_proto_init() {
	if File_spire_api_server_agent_v1_agent_proto != nil {
		return
	}
	file_spire_api_server_agent_v1_agent_proto_msgTypes[7].OneofWrappers = []any{
		(*AttestAgentRequest_Params_)(nil),
		(*AttestAgentRequest_ChallengeResponse)(nil),
	}
	file_spire_api_server_agent_v1_agent_proto_msgTypes[8].OneofWrappers = []any{
		(*AttestAgentResponse_Result_)(nil),
		(*AttestAgentResponse_Challenge)(nil),
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: unsafe.Slice(unsafe.StringData(file_spire_api_server_agent_v1_agent_proto_rawDesc), len(file_spire_api_server_agent_v1_agent_proto_rawDesc)),
			NumEnums:      0,
			NumMessages:   19,
			NumExtensions: 0,
			NumServices:   1,
		},
		GoTypes:           file_spire_api_server_agent_v1_agent_proto_goTypes,
		DependencyIndexes: file_spire_api_server_agent_v1_agent_proto_depIdxs,
		MessageInfos:      file_spire_api_server_agent_v1_agent_proto_msgTypes,
	}.Build()
	File_spire_api_server_agent_v1_agent_proto = out.File
	file_spire_api_server_agent_v1_agent_proto_goTypes = nil
	file_spire_api_server_agent_v1_agent_proto_depIdxs = nil
}
