// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.36.7
// 	protoc        v6.30.2
// source: spire/api/types/jwtsvid.proto

package types

import (
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	reflect "reflect"
	sync "sync"
	unsafe "unsafe"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

// JWT SPIFFE Verifiable Identity Document. It contains the raw JWT token
// as well as a few denormalized fields for convenience.
type JWTSVID struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// The serialized JWT token.
	Token string `protobuf:"bytes,1,opt,name=token,proto3" json:"token,omitempty"`
	// The SPIFFE ID of the JWT-SVID.
	Id *SPIFFEID `protobuf:"bytes,2,opt,name=id,proto3" json:"id,omitempty"`
	// Expiration timestamp (seconds since Unix epoch).
	ExpiresAt int64 `protobuf:"varint,3,opt,name=expires_at,json=expiresAt,proto3" json:"expires_at,omitempty"`
	// Issuance timestamp (seconds since Unix epoch).
	IssuedAt int64 `protobuf:"varint,4,opt,name=issued_at,json=issuedAt,proto3" json:"issued_at,omitempty"`
	// Optional. An operator-specified string used to provide guidance on how this
	// identity should be used by a workload when more than one SVID is returned.
	// For example, `internal` and `external` to indicate an SVID for internal or
	// external use, respectively.
	Hint          string `protobuf:"bytes,5,opt,name=hint,proto3" json:"hint,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *JWTSVID) Reset() {
	*x = JWTSVID{}
	mi := &file_spire_api_types_jwtsvid_proto_msgTypes[0]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *JWTSVID) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*JWTSVID) ProtoMessage() {}

func (x *JWTSVID) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_types_jwtsvid_proto_msgTypes[0]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use JWTSVID.ProtoReflect.Descriptor instead.
func (*JWTSVID) Descriptor() ([]byte, []int) {
	return file_spire_api_types_jwtsvid_proto_rawDescGZIP(), []int{0}
}

func (x *JWTSVID) GetToken() string {
	if x != nil {
		return x.Token
	}
	return ""
}

func (x *JWTSVID) GetId() *SPIFFEID {
	if x != nil {
		return x.Id
	}
	return nil
}

func (x *JWTSVID) GetExpiresAt() int64 {
	if x != nil {
		return x.ExpiresAt
	}
	return 0
}

func (x *JWTSVID) GetIssuedAt() int64 {
	if x != nil {
		return x.IssuedAt
	}
	return 0
}

func (x *JWTSVID) GetHint() string {
	if x != nil {
		return x.Hint
	}
	return ""
}

var File_spire_api_types_jwtsvid_proto protoreflect.FileDescriptor

const file_spire_api_types_jwtsvid_proto_rawDesc = "" +
	"\n" +
	"\x1dspire/api/types/jwtsvid.proto\x12\x0fspire.api.types\x1a\x1espire/api/types/spiffeid.proto\"\x9a\x01\n" +
	"\aJWTSVID\x12\x14\n" +
	"\x05token\x18\x01 \x01(\tR\x05token\x12)\n" +
	"\x02id\x18\x02 \x01(\v2\x19.spire.api.types.SPIFFEIDR\x02id\x12\x1d\n" +
	"\n" +
	"expires_at\x18\x03 \x01(\x03R\texpiresAt\x12\x1b\n" +
	"\tissued_at\x18\x04 \x01(\x03R\bissuedAt\x12\x12\n" +
	"\x04hint\x18\x05 \x01(\tR\x04hintB7Z5github.com/spiffe/spire-api-sdk/proto/spire/api/typesb\x06proto3"

var (
	file_spire_api_types_jwtsvid_proto_rawDescOnce sync.Once
	file_spire_api_types_jwtsvid_proto_rawDescData []byte
)

func file_spire_api_types_jwtsvid_proto_rawDescGZIP() []byte {
	file_spire_api_types_jwtsvid_proto_rawDescOnce.Do(func() {
		file_spire_api_types_jwtsvid_proto_rawDescData = protoimpl.X.CompressGZIP(unsafe.Slice(unsafe.StringData(file_spire_api_types_jwtsvid_proto_rawDesc), len(file_spire_api_types_jwtsvid_proto_rawDesc)))
	})
	return file_spire_api_types_jwtsvid_proto_rawDescData
}

var file_spire_api_types_jwtsvid_proto_msgTypes = make([]protoimpl.MessageInfo, 1)
var file_spire_api_types_jwtsvid_proto_goTypes = []any{
	(*JWTSVID)(nil),  // 0: spire.api.types.JWTSVID
	(*SPIFFEID)(nil), // 1: spire.api.types.SPIFFEID
}
var file_spire_api_types_jwtsvid_proto_depIdxs = []int32{
	1, // 0: spire.api.types.JWTSVID.id:type_name -> spire.api.types.SPIFFEID
	1, // [1:1] is the sub-list for method output_type
	1, // [1:1] is the sub-list for method input_type
	1, // [1:1] is the sub-list for extension type_name
	1, // [1:1] is the sub-list for extension extendee
	0, // [0:1] is the sub-list for field type_name
}

func init() { file_spire_api_types_jwtsvid_proto_init() }
func file_spire_api_types_jwtsvid_proto_init() {
	if File_spire_api_types_jwtsvid_proto != nil {
		return
	}
	file_spire_api_types_spiffeid_proto_init()
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: unsafe.Slice(unsafe.StringData(file_spire_api_types_jwtsvid_proto_rawDesc), len(file_spire_api_types_jwtsvid_proto_rawDesc)),
			NumEnums:      0,
			NumMessages:   1,
			NumExtensions: 0,
			NumServices:   0,
		},
		GoTypes:           file_spire_api_types_jwtsvid_proto_goTypes,
		DependencyIndexes: file_spire_api_types_jwtsvid_proto_depIdxs,
		MessageInfos:      file_spire_api_types_jwtsvid_proto_msgTypes,
	}.Build()
	File_spire_api_types_jwtsvid_proto = out.File
	file_spire_api_types_jwtsvid_proto_goTypes = nil
	file_spire_api_types_jwtsvid_proto_depIdxs = nil
}
