// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.36.7
// 	protoc        v6.30.2
// source: spire/api/types/status.proto

package types

import (
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	reflect "reflect"
	sync "sync"
	unsafe "unsafe"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type PermissionDeniedDetails_Reason int32

const (
	// Reason unknown.
	PermissionDeniedDetails_UNKNOWN PermissionDeniedDetails_Reason = 0
	// Agent identity has expired.
	PermissionDeniedDetails_AGENT_EXPIRED PermissionDeniedDetails_Reason = 1
	// Identity is not an attested agent.
	PermissionDeniedDetails_AGENT_NOT_ATTESTED PermissionDeniedDetails_Reason = 2
	// Identity is not the active agent identity.
	PermissionDeniedDetails_AGENT_NOT_ACTIVE PermissionDeniedDetails_Reason = 3
	// Agent has been banned.
	PermissionDeniedDetails_AGENT_BANNED PermissionDeniedDetails_Reason = 4
	// Agent attempted to renew SVID, but should reattest instead
	PermissionDeniedDetails_AGENT_MUST_REATTEST PermissionDeniedDetails_Reason = 5
)

// Enum value maps for PermissionDeniedDetails_Reason.
var (
	PermissionDeniedDetails_Reason_name = map[int32]string{
		0: "UNKNOWN",
		1: "AGENT_EXPIRED",
		2: "AGENT_NOT_ATTESTED",
		3: "AGENT_NOT_ACTIVE",
		4: "AGENT_BANNED",
		5: "AGENT_MUST_REATTEST",
	}
	PermissionDeniedDetails_Reason_value = map[string]int32{
		"UNKNOWN":             0,
		"AGENT_EXPIRED":       1,
		"AGENT_NOT_ATTESTED":  2,
		"AGENT_NOT_ACTIVE":    3,
		"AGENT_BANNED":        4,
		"AGENT_MUST_REATTEST": 5,
	}
)

func (x PermissionDeniedDetails_Reason) Enum() *PermissionDeniedDetails_Reason {
	p := new(PermissionDeniedDetails_Reason)
	*p = x
	return p
}

func (x PermissionDeniedDetails_Reason) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (PermissionDeniedDetails_Reason) Descriptor() protoreflect.EnumDescriptor {
	return file_spire_api_types_status_proto_enumTypes[0].Descriptor()
}

func (PermissionDeniedDetails_Reason) Type() protoreflect.EnumType {
	return &file_spire_api_types_status_proto_enumTypes[0]
}

func (x PermissionDeniedDetails_Reason) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Use PermissionDeniedDetails_Reason.Descriptor instead.
func (PermissionDeniedDetails_Reason) EnumDescriptor() ([]byte, []int) {
	return file_spire_api_types_status_proto_rawDescGZIP(), []int{1, 0}
}

type Status struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// A status code, which should be an enum value of google.rpc.Code.
	Code int32 `protobuf:"varint,1,opt,name=code,proto3" json:"code,omitempty"`
	// A developer-facing error message.
	Message       string `protobuf:"bytes,2,opt,name=message,proto3" json:"message,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *Status) Reset() {
	*x = Status{}
	mi := &file_spire_api_types_status_proto_msgTypes[0]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *Status) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Status) ProtoMessage() {}

func (x *Status) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_types_status_proto_msgTypes[0]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Status.ProtoReflect.Descriptor instead.
func (*Status) Descriptor() ([]byte, []int) {
	return file_spire_api_types_status_proto_rawDescGZIP(), []int{0}
}

func (x *Status) GetCode() int32 {
	if x != nil {
		return x.Code
	}
	return 0
}

func (x *Status) GetMessage() string {
	if x != nil {
		return x.Message
	}
	return ""
}

type PermissionDeniedDetails struct {
	state         protoimpl.MessageState         `protogen:"open.v1"`
	Reason        PermissionDeniedDetails_Reason `protobuf:"varint,1,opt,name=reason,proto3,enum=spire.api.types.PermissionDeniedDetails_Reason" json:"reason,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *PermissionDeniedDetails) Reset() {
	*x = PermissionDeniedDetails{}
	mi := &file_spire_api_types_status_proto_msgTypes[1]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *PermissionDeniedDetails) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*PermissionDeniedDetails) ProtoMessage() {}

func (x *PermissionDeniedDetails) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_types_status_proto_msgTypes[1]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use PermissionDeniedDetails.ProtoReflect.Descriptor instead.
func (*PermissionDeniedDetails) Descriptor() ([]byte, []int) {
	return file_spire_api_types_status_proto_rawDescGZIP(), []int{1}
}

func (x *PermissionDeniedDetails) GetReason() PermissionDeniedDetails_Reason {
	if x != nil {
		return x.Reason
	}
	return PermissionDeniedDetails_UNKNOWN
}

var File_spire_api_types_status_proto protoreflect.FileDescriptor

const file_spire_api_types_status_proto_rawDesc = "" +
	"\n" +
	"\x1cspire/api/types/status.proto\x12\x0fspire.api.types\"6\n" +
	"\x06Status\x12\x12\n" +
	"\x04code\x18\x01 \x01(\x05R\x04code\x12\x18\n" +
	"\amessage\x18\x02 \x01(\tR\amessage\"\xe6\x01\n" +
	"\x17PermissionDeniedDetails\x12G\n" +
	"\x06reason\x18\x01 \x01(\x0e2/.spire.api.types.PermissionDeniedDetails.ReasonR\x06reason\"\x81\x01\n" +
	"\x06Reason\x12\v\n" +
	"\aUNKNOWN\x10\x00\x12\x11\n" +
	"\rAGENT_EXPIRED\x10\x01\x12\x16\n" +
	"\x12AGENT_NOT_ATTESTED\x10\x02\x12\x14\n" +
	"\x10AGENT_NOT_ACTIVE\x10\x03\x12\x10\n" +
	"\fAGENT_BANNED\x10\x04\x12\x17\n" +
	"\x13AGENT_MUST_REATTEST\x10\x05B7Z5github.com/spiffe/spire-api-sdk/proto/spire/api/typesb\x06proto3"

var (
	file_spire_api_types_status_proto_rawDescOnce sync.Once
	file_spire_api_types_status_proto_rawDescData []byte
)

func file_spire_api_types_status_proto_rawDescGZIP() []byte {
	file_spire_api_types_status_proto_rawDescOnce.Do(func() {
		file_spire_api_types_status_proto_rawDescData = protoimpl.X.CompressGZIP(unsafe.Slice(unsafe.StringData(file_spire_api_types_status_proto_rawDesc), len(file_spire_api_types_status_proto_rawDesc)))
	})
	return file_spire_api_types_status_proto_rawDescData
}

var file_spire_api_types_status_proto_enumTypes = make([]protoimpl.EnumInfo, 1)
var file_spire_api_types_status_proto_msgTypes = make([]protoimpl.MessageInfo, 2)
var file_spire_api_types_status_proto_goTypes = []any{
	(PermissionDeniedDetails_Reason)(0), // 0: spire.api.types.PermissionDeniedDetails.Reason
	(*Status)(nil),                      // 1: spire.api.types.Status
	(*PermissionDeniedDetails)(nil),     // 2: spire.api.types.PermissionDeniedDetails
}
var file_spire_api_types_status_proto_depIdxs = []int32{
	0, // 0: spire.api.types.PermissionDeniedDetails.reason:type_name -> spire.api.types.PermissionDeniedDetails.Reason
	1, // [1:1] is the sub-list for method output_type
	1, // [1:1] is the sub-list for method input_type
	1, // [1:1] is the sub-list for extension type_name
	1, // [1:1] is the sub-list for extension extendee
	0, // [0:1] is the sub-list for field type_name
}

func init() { file_spire_api_types_status_proto_init() }
func file_spire_api_types_status_proto_init() {
	if File_spire_api_types_status_proto != nil {
		return
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: unsafe.Slice(unsafe.StringData(file_spire_api_types_status_proto_rawDesc), len(file_spire_api_types_status_proto_rawDesc)),
			NumEnums:      1,
			NumMessages:   2,
			NumExtensions: 0,
			NumServices:   0,
		},
		GoTypes:           file_spire_api_types_status_proto_goTypes,
		DependencyIndexes: file_spire_api_types_status_proto_depIdxs,
		EnumInfos:         file_spire_api_types_status_proto_enumTypes,
		MessageInfos:      file_spire_api_types_status_proto_msgTypes,
	}.Build()
	File_spire_api_types_status_proto = out.File
	file_spire_api_types_status_proto_goTypes = nil
	file_spire_api_types_status_proto_depIdxs = nil
}
