// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.36.7
// 	protoc        v6.30.2
// source: spire/api/types/agent.proto

package types

import (
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	_ "google.golang.org/protobuf/types/known/wrapperspb"
	reflect "reflect"
	sync "sync"
	unsafe "unsafe"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type Agent struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Output only. SPIFFE ID of the agent.
	Id *SPIFFEID `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// Output only. The method by which the agent attested.
	AttestationType string `protobuf:"bytes,2,opt,name=attestation_type,json=attestationType,proto3" json:"attestation_type,omitempty"`
	// Output only. The X509-SVID serial number.
	X509SvidSerialNumber string `protobuf:"bytes,3,opt,name=x509svid_serial_number,json=x509svidSerialNumber,proto3" json:"x509svid_serial_number,omitempty"`
	// Output only. The X509-SVID expiration (seconds since Unix epoch).
	X509SvidExpiresAt int64 `protobuf:"varint,4,opt,name=x509svid_expires_at,json=x509svidExpiresAt,proto3" json:"x509svid_expires_at,omitempty"`
	// Output only. The selectors attributed to the agent during attestation.
	Selectors []*Selector `protobuf:"bytes,5,rep,name=selectors,proto3" json:"selectors,omitempty"`
	// Output only. Whether or not the agent is banned.
	Banned bool `protobuf:"varint,6,opt,name=banned,proto3" json:"banned,omitempty"`
	// Output only. Whether or not the agent can re-attest.
	CanReattest bool `protobuf:"varint,7,opt,name=can_reattest,json=canReattest,proto3" json:"can_reattest,omitempty"`
	// Output only. Optional. The version of the agent.
	AgentVersion  string `protobuf:"bytes,8,opt,name=agent_version,json=agentVersion,proto3" json:"agent_version,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *Agent) Reset() {
	*x = Agent{}
	mi := &file_spire_api_types_agent_proto_msgTypes[0]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *Agent) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Agent) ProtoMessage() {}

func (x *Agent) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_types_agent_proto_msgTypes[0]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Agent.ProtoReflect.Descriptor instead.
func (*Agent) Descriptor() ([]byte, []int) {
	return file_spire_api_types_agent_proto_rawDescGZIP(), []int{0}
}

func (x *Agent) GetId() *SPIFFEID {
	if x != nil {
		return x.Id
	}
	return nil
}

func (x *Agent) GetAttestationType() string {
	if x != nil {
		return x.AttestationType
	}
	return ""
}

func (x *Agent) GetX509SvidSerialNumber() string {
	if x != nil {
		return x.X509SvidSerialNumber
	}
	return ""
}

func (x *Agent) GetX509SvidExpiresAt() int64 {
	if x != nil {
		return x.X509SvidExpiresAt
	}
	return 0
}

func (x *Agent) GetSelectors() []*Selector {
	if x != nil {
		return x.Selectors
	}
	return nil
}

func (x *Agent) GetBanned() bool {
	if x != nil {
		return x.Banned
	}
	return false
}

func (x *Agent) GetCanReattest() bool {
	if x != nil {
		return x.CanReattest
	}
	return false
}

func (x *Agent) GetAgentVersion() string {
	if x != nil {
		return x.AgentVersion
	}
	return ""
}

type AgentMask struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// attestation_type field mask
	AttestationType bool `protobuf:"varint,2,opt,name=attestation_type,json=attestationType,proto3" json:"attestation_type,omitempty"`
	// x509svid_serial_number field mask
	X509SvidSerialNumber bool `protobuf:"varint,3,opt,name=x509svid_serial_number,json=x509svidSerialNumber,proto3" json:"x509svid_serial_number,omitempty"`
	// x509svid_expires_at field mask
	X509SvidExpiresAt bool `protobuf:"varint,4,opt,name=x509svid_expires_at,json=x509svidExpiresAt,proto3" json:"x509svid_expires_at,omitempty"`
	// selectors field mask
	Selectors bool `protobuf:"varint,5,opt,name=selectors,proto3" json:"selectors,omitempty"`
	// banned field mask
	Banned bool `protobuf:"varint,6,opt,name=banned,proto3" json:"banned,omitempty"`
	// can_reattest field mask
	CanReattest bool `protobuf:"varint,7,opt,name=can_reattest,json=canReattest,proto3" json:"can_reattest,omitempty"`
	// agent_version field mask
	AgentVersion  bool `protobuf:"varint,8,opt,name=agent_version,json=agentVersion,proto3" json:"agent_version,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *AgentMask) Reset() {
	*x = AgentMask{}
	mi := &file_spire_api_types_agent_proto_msgTypes[1]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *AgentMask) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*AgentMask) ProtoMessage() {}

func (x *AgentMask) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_types_agent_proto_msgTypes[1]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use AgentMask.ProtoReflect.Descriptor instead.
func (*AgentMask) Descriptor() ([]byte, []int) {
	return file_spire_api_types_agent_proto_rawDescGZIP(), []int{1}
}

func (x *AgentMask) GetAttestationType() bool {
	if x != nil {
		return x.AttestationType
	}
	return false
}

func (x *AgentMask) GetX509SvidSerialNumber() bool {
	if x != nil {
		return x.X509SvidSerialNumber
	}
	return false
}

func (x *AgentMask) GetX509SvidExpiresAt() bool {
	if x != nil {
		return x.X509SvidExpiresAt
	}
	return false
}

func (x *AgentMask) GetSelectors() bool {
	if x != nil {
		return x.Selectors
	}
	return false
}

func (x *AgentMask) GetBanned() bool {
	if x != nil {
		return x.Banned
	}
	return false
}

func (x *AgentMask) GetCanReattest() bool {
	if x != nil {
		return x.CanReattest
	}
	return false
}

func (x *AgentMask) GetAgentVersion() bool {
	if x != nil {
		return x.AgentVersion
	}
	return false
}

var File_spire_api_types_agent_proto protoreflect.FileDescriptor

const file_spire_api_types_agent_proto_rawDesc = "" +
	"\n" +
	"\x1bspire/api/types/agent.proto\x12\x0fspire.api.types\x1a\x1espire/api/types/selector.proto\x1a\x1espire/api/types/spiffeid.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xdc\x02\n" +
	"\x05Agent\x12)\n" +
	"\x02id\x18\x01 \x01(\v2\x19.spire.api.types.SPIFFEIDR\x02id\x12)\n" +
	"\x10attestation_type\x18\x02 \x01(\tR\x0fattestationType\x124\n" +
	"\x16x509svid_serial_number\x18\x03 \x01(\tR\x14x509svidSerialNumber\x12.\n" +
	"\x13x509svid_expires_at\x18\x04 \x01(\x03R\x11x509svidExpiresAt\x127\n" +
	"\tselectors\x18\x05 \x03(\v2\x19.spire.api.types.SelectorR\tselectors\x12\x16\n" +
	"\x06banned\x18\x06 \x01(\bR\x06banned\x12!\n" +
	"\fcan_reattest\x18\a \x01(\bR\vcanReattest\x12#\n" +
	"\ragent_version\x18\b \x01(\tR\fagentVersion\"\x9a\x02\n" +
	"\tAgentMask\x12)\n" +
	"\x10attestation_type\x18\x02 \x01(\bR\x0fattestationType\x124\n" +
	"\x16x509svid_serial_number\x18\x03 \x01(\bR\x14x509svidSerialNumber\x12.\n" +
	"\x13x509svid_expires_at\x18\x04 \x01(\bR\x11x509svidExpiresAt\x12\x1c\n" +
	"\tselectors\x18\x05 \x01(\bR\tselectors\x12\x16\n" +
	"\x06banned\x18\x06 \x01(\bR\x06banned\x12!\n" +
	"\fcan_reattest\x18\a \x01(\bR\vcanReattest\x12#\n" +
	"\ragent_version\x18\b \x01(\bR\fagentVersionB7Z5github.com/spiffe/spire-api-sdk/proto/spire/api/typesb\x06proto3"

var (
	file_spire_api_types_agent_proto_rawDescOnce sync.Once
	file_spire_api_types_agent_proto_rawDescData []byte
)

func file_spire_api_types_agent_proto_rawDescGZIP() []byte {
	file_spire_api_types_agent_proto_rawDescOnce.Do(func() {
		file_spire_api_types_agent_proto_rawDescData = protoimpl.X.CompressGZIP(unsafe.Slice(unsafe.StringData(file_spire_api_types_agent_proto_rawDesc), len(file_spire_api_types_agent_proto_rawDesc)))
	})
	return file_spire_api_types_agent_proto_rawDescData
}

var file_spire_api_types_agent_proto_msgTypes = make([]protoimpl.MessageInfo, 2)
var file_spire_api_types_agent_proto_goTypes = []any{
	(*Agent)(nil),     // 0: spire.api.types.Agent
	(*AgentMask)(nil), // 1: spire.api.types.AgentMask
	(*SPIFFEID)(nil),  // 2: spire.api.types.SPIFFEID
	(*Selector)(nil),  // 3: spire.api.types.Selector
}
var file_spire_api_types_agent_proto_depIdxs = []int32{
	2, // 0: spire.api.types.Agent.id:type_name -> spire.api.types.SPIFFEID
	3, // 1: spire.api.types.Agent.selectors:type_name -> spire.api.types.Selector
	2, // [2:2] is the sub-list for method output_type
	2, // [2:2] is the sub-list for method input_type
	2, // [2:2] is the sub-list for extension type_name
	2, // [2:2] is the sub-list for extension extendee
	0, // [0:2] is the sub-list for field type_name
}

func init() { file_spire_api_types_agent_proto_init() }
func file_spire_api_types_agent_proto_init() {
	if File_spire_api_types_agent_proto != nil {
		return
	}
	file_spire_api_types_selector_proto_init()
	file_spire_api_types_spiffeid_proto_init()
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: unsafe.Slice(unsafe.StringData(file_spire_api_types_agent_proto_rawDesc), len(file_spire_api_types_agent_proto_rawDesc)),
			NumEnums:      0,
			NumMessages:   2,
			NumExtensions: 0,
			NumServices:   0,
		},
		GoTypes:           file_spire_api_types_agent_proto_goTypes,
		DependencyIndexes: file_spire_api_types_agent_proto_depIdxs,
		MessageInfos:      file_spire_api_types_agent_proto_msgTypes,
	}.Build()
	File_spire_api_types_agent_proto = out.File
	file_spire_api_types_agent_proto_goTypes = nil
	file_spire_api_types_agent_proto_depIdxs = nil
}
