// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.36.7
// 	protoc        v6.30.2
// source: spire/api/agent/debug/v1/debug.proto

package debugv1

import (
	types "github.com/spiffe/spire-api-sdk/proto/spire/api/types"
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	reflect "reflect"
	sync "sync"
	unsafe "unsafe"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type GetInfoRequest struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetInfoRequest) Reset() {
	*x = GetInfoRequest{}
	mi := &file_spire_api_agent_debug_v1_debug_proto_msgTypes[0]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetInfoRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetInfoRequest) ProtoMessage() {}

func (x *GetInfoRequest) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_agent_debug_v1_debug_proto_msgTypes[0]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetInfoRequest.ProtoReflect.Descriptor instead.
func (*GetInfoRequest) Descriptor() ([]byte, []int) {
	return file_spire_api_agent_debug_v1_debug_proto_rawDescGZIP(), []int{0}
}

type GetInfoResponse struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Agent SVID chain
	SvidChain []*GetInfoResponse_Cert `protobuf:"bytes,1,rep,name=svid_chain,json=svidChain,proto3" json:"svid_chain,omitempty"`
	// Agent uptime in seconds
	Uptime int32 `protobuf:"varint,2,opt,name=uptime,proto3" json:"uptime,omitempty"`
	// Number of SVIDs cached in memory
	// Deprecated in favor of cached_x509_svids_count, cached_jwt_svids_count, and cached_svidstore_x509_svids_count
	//
	// Deprecated: Marked as deprecated in spire/api/agent/debug/v1/debug.proto.
	SvidsCount int32 `protobuf:"varint,3,opt,name=svids_count,json=svidsCount,proto3" json:"svids_count,omitempty"`
	// last successful sync with server (in seconds since unix epoch)
	LastSyncSuccess int64 `protobuf:"varint,4,opt,name=last_sync_success,json=lastSyncSuccess,proto3" json:"last_sync_success,omitempty"`
	// Number of X.509-SVIDs in Agent primary in-memory cache
	CachedX509SvidsCount int32 `protobuf:"varint,5,opt,name=cached_x509_svids_count,json=cachedX509SvidsCount,proto3" json:"cached_x509_svids_count,omitempty"`
	// Number of JWT-SVIDs in Agent primary in-memory cache
	CachedJwtSvidsCount int32 `protobuf:"varint,6,opt,name=cached_jwt_svids_count,json=cachedJwtSvidsCount,proto3" json:"cached_jwt_svids_count,omitempty"`
	// Number of X.509-SVIDs in Agent svidstore in-memory cache
	CachedSvidstoreX509SvidsCount int32 `protobuf:"varint,7,opt,name=cached_svidstore_x509_svids_count,json=cachedSvidstoreX509SvidsCount,proto3" json:"cached_svidstore_x509_svids_count,omitempty"`
	unknownFields                 protoimpl.UnknownFields
	sizeCache                     protoimpl.SizeCache
}

func (x *GetInfoResponse) Reset() {
	*x = GetInfoResponse{}
	mi := &file_spire_api_agent_debug_v1_debug_proto_msgTypes[1]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetInfoResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetInfoResponse) ProtoMessage() {}

func (x *GetInfoResponse) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_agent_debug_v1_debug_proto_msgTypes[1]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetInfoResponse.ProtoReflect.Descriptor instead.
func (*GetInfoResponse) Descriptor() ([]byte, []int) {
	return file_spire_api_agent_debug_v1_debug_proto_rawDescGZIP(), []int{1}
}

func (x *GetInfoResponse) GetSvidChain() []*GetInfoResponse_Cert {
	if x != nil {
		return x.SvidChain
	}
	return nil
}

func (x *GetInfoResponse) GetUptime() int32 {
	if x != nil {
		return x.Uptime
	}
	return 0
}

// Deprecated: Marked as deprecated in spire/api/agent/debug/v1/debug.proto.
func (x *GetInfoResponse) GetSvidsCount() int32 {
	if x != nil {
		return x.SvidsCount
	}
	return 0
}

func (x *GetInfoResponse) GetLastSyncSuccess() int64 {
	if x != nil {
		return x.LastSyncSuccess
	}
	return 0
}

func (x *GetInfoResponse) GetCachedX509SvidsCount() int32 {
	if x != nil {
		return x.CachedX509SvidsCount
	}
	return 0
}

func (x *GetInfoResponse) GetCachedJwtSvidsCount() int32 {
	if x != nil {
		return x.CachedJwtSvidsCount
	}
	return 0
}

func (x *GetInfoResponse) GetCachedSvidstoreX509SvidsCount() int32 {
	if x != nil {
		return x.CachedSvidstoreX509SvidsCount
	}
	return 0
}

type GetInfoResponse_Cert struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Cerfificate SPIFFE ID
	Id *types.SPIFFEID `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// Expiration time
	ExpiresAt int64 `protobuf:"varint,2,opt,name=expires_at,json=expiresAt,proto3" json:"expires_at,omitempty"`
	// Subject
	Subject       string `protobuf:"bytes,3,opt,name=subject,proto3" json:"subject,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetInfoResponse_Cert) Reset() {
	*x = GetInfoResponse_Cert{}
	mi := &file_spire_api_agent_debug_v1_debug_proto_msgTypes[2]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetInfoResponse_Cert) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetInfoResponse_Cert) ProtoMessage() {}

func (x *GetInfoResponse_Cert) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_agent_debug_v1_debug_proto_msgTypes[2]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetInfoResponse_Cert.ProtoReflect.Descriptor instead.
func (*GetInfoResponse_Cert) Descriptor() ([]byte, []int) {
	return file_spire_api_agent_debug_v1_debug_proto_rawDescGZIP(), []int{1, 0}
}

func (x *GetInfoResponse_Cert) GetId() *types.SPIFFEID {
	if x != nil {
		return x.Id
	}
	return nil
}

func (x *GetInfoResponse_Cert) GetExpiresAt() int64 {
	if x != nil {
		return x.ExpiresAt
	}
	return 0
}

func (x *GetInfoResponse_Cert) GetSubject() string {
	if x != nil {
		return x.Subject
	}
	return ""
}

var File_spire_api_agent_debug_v1_debug_proto protoreflect.FileDescriptor

const file_spire_api_agent_debug_v1_debug_proto_rawDesc = "" +
	"\n" +
	"$spire/api/agent/debug/v1/debug.proto\x12\x14spire.agent.debug.v1\x1a\x1espire/api/types/spiffeid.proto\"\x10\n" +
	"\x0eGetInfoRequest\"\xe7\x03\n" +
	"\x0fGetInfoResponse\x12I\n" +
	"\n" +
	"svid_chain\x18\x01 \x03(\v2*.spire.agent.debug.v1.GetInfoResponse.CertR\tsvidChain\x12\x16\n" +
	"\x06uptime\x18\x02 \x01(\x05R\x06uptime\x12#\n" +
	"\vsvids_count\x18\x03 \x01(\x05B\x02\x18\x01R\n" +
	"svidsCount\x12*\n" +
	"\x11last_sync_success\x18\x04 \x01(\x03R\x0flastSyncSuccess\x125\n" +
	"\x17cached_x509_svids_count\x18\x05 \x01(\x05R\x14cachedX509SvidsCount\x123\n" +
	"\x16cached_jwt_svids_count\x18\x06 \x01(\x05R\x13cachedJwtSvidsCount\x12H\n" +
	"!cached_svidstore_x509_svids_count\x18\a \x01(\x05R\x1dcachedSvidstoreX509SvidsCount\x1aj\n" +
	"\x04Cert\x12)\n" +
	"\x02id\x18\x01 \x01(\v2\x19.spire.api.types.SPIFFEIDR\x02id\x12\x1d\n" +
	"\n" +
	"expires_at\x18\x02 \x01(\x03R\texpiresAt\x12\x18\n" +
	"\asubject\x18\x03 \x01(\tR\asubject2_\n" +
	"\x05Debug\x12V\n" +
	"\aGetInfo\x12$.spire.agent.debug.v1.GetInfoRequest\x1a%.spire.agent.debug.v1.GetInfoResponseBHZFgithub.com/spiffe/spire-api-sdk/proto/spire/api/agent/debug/v1;debugv1b\x06proto3"

var (
	file_spire_api_agent_debug_v1_debug_proto_rawDescOnce sync.Once
	file_spire_api_agent_debug_v1_debug_proto_rawDescData []byte
)

func file_spire_api_agent_debug_v1_debug_proto_rawDescGZIP() []byte {
	file_spire_api_agent_debug_v1_debug_proto_rawDescOnce.Do(func() {
		file_spire_api_agent_debug_v1_debug_proto_rawDescData = protoimpl.X.CompressGZIP(unsafe.Slice(unsafe.StringData(file_spire_api_agent_debug_v1_debug_proto_rawDesc), len(file_spire_api_agent_debug_v1_debug_proto_rawDesc)))
	})
	return file_spire_api_agent_debug_v1_debug_proto_rawDescData
}

var file_spire_api_agent_debug_v1_debug_proto_msgTypes = make([]protoimpl.MessageInfo, 3)
var file_spire_api_agent_debug_v1_debug_proto_goTypes = []any{
	(*GetInfoRequest)(nil),       // 0: spire.agent.debug.v1.GetInfoRequest
	(*GetInfoResponse)(nil),      // 1: spire.agent.debug.v1.GetInfoResponse
	(*GetInfoResponse_Cert)(nil), // 2: spire.agent.debug.v1.GetInfoResponse.Cert
	(*types.SPIFFEID)(nil),       // 3: spire.api.types.SPIFFEID
}
var file_spire_api_agent_debug_v1_debug_proto_depIdxs = []int32{
	2, // 0: spire.agent.debug.v1.GetInfoResponse.svid_chain:type_name -> spire.agent.debug.v1.GetInfoResponse.Cert
	3, // 1: spire.agent.debug.v1.GetInfoResponse.Cert.id:type_name -> spire.api.types.SPIFFEID
	0, // 2: spire.agent.debug.v1.Debug.GetInfo:input_type -> spire.agent.debug.v1.GetInfoRequest
	1, // 3: spire.agent.debug.v1.Debug.GetInfo:output_type -> spire.agent.debug.v1.GetInfoResponse
	3, // [3:4] is the sub-list for method output_type
	2, // [2:3] is the sub-list for method input_type
	2, // [2:2] is the sub-list for extension type_name
	2, // [2:2] is the sub-list for extension extendee
	0, // [0:2] is the sub-list for field type_name
}

func init() { file_spire_api_agent_debug_v1_debug_proto_init() }
func file_spire_api_agent_debug_v1_debug_proto_init() {
	if File_spire_api_agent_debug_v1_debug_proto != nil {
		return
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: unsafe.Slice(unsafe.StringData(file_spire_api_agent_debug_v1_debug_proto_rawDesc), len(file_spire_api_agent_debug_v1_debug_proto_rawDesc)),
			NumEnums:      0,
			NumMessages:   3,
			NumExtensions: 0,
			NumServices:   1,
		},
		GoTypes:           file_spire_api_agent_debug_v1_debug_proto_goTypes,
		DependencyIndexes: file_spire_api_agent_debug_v1_debug_proto_depIdxs,
		MessageInfos:      file_spire_api_agent_debug_v1_debug_proto_msgTypes,
	}.Build()
	File_spire_api_agent_debug_v1_debug_proto = out.File
	file_spire_api_agent_debug_v1_debug_proto_goTypes = nil
	file_spire_api_agent_debug_v1_debug_proto_depIdxs = nil
}
